#ifndef _VELIB_VE_REGS_H_
#define _VELIB_VE_REGS_H_

#include <velib/types/types.h>
#include <velib/vecan/regs_helpers.h>
#include <velib/vecan/regs_payload.h>

/// @addtogroup VELIB_VECAN_REG
/// @{

/// Register ids are un16
typedef un16 VeRegId;

/*[[[cog import gen_signal_definition ]]]*/
/** only internal! */
#define VE_REG_INVALID 0x0000

/** VREQ {un16 = VReg Requested : un16 = VReg Mask} */
#define VE_REG_REQ 0x0001

/** VACK {un16 = VReg ACKed : un8 = Data : un8 = Code} */
#define VE_REG_ACK 0x0002

/** Ping {stringFixed[4] = payload, returned in the reply} */
#define VE_REG_PING 0x0003

/** Restore Defaults */
#define VE_REG_RESTORE_DEFAULT 0x0004

/** UDF.Start {un8 = vup instance} */
#define VE_REG_UPDATE_ENABLE 0x0010

/** UDF.End */
#define VE_REG_UPDATE_END 0x0011

/** UDF.Data */
#define VE_REG_UPDATE_DATA 0x0012

/** Test Mode {stringFixed[4] = Password} */
#define VE_REG_TEST_MODE 0x0020

/**
 * Microcontroller reset detection {un8 = reset flag, 0 = reset value, 1 =
 * written by tester}
 */
#define VE_REG_RESET_DETECTION 0x0021

/**
 *  {un8 = release, 0 = product failed, 1 = product passed testing and
 * calibration}
 */
#define VE_REG_TEST_PRODUCT_RELEASE 0x0022

/** Settings dump {un16 = offset : un16 = size} */
#define VE_REG_DUMP_PAGE 0x0023

/** Clear service history command */
#define VE_REG_CLEAR_SERVICE_HISTORY 0x0024

/** Tunnel */
#define VE_REG_TUNNEL 0x0030

/**
 * Unique id 0 {un16 = Controller id : un16 = Site id, 0x02A8 = Arrow Europe,
 * 0xE7D2 = Victron Energy}
 */
#define VE_REG_UNIQUE_ID_0 0x0040

/** Unique id 1 {un32 = Id} */
#define VE_REG_UNIQUE_ID_1 0x0041

/** Unique id 2 {un32 = Id} */
#define VE_REG_UNIQUE_ID_2 0x0042

/** Unique id 3 {un32 = Id} */
#define VE_REG_UNIQUE_ID_3 0x0043

/** Unique id 4 {un32 = Id} */
#define VE_REG_UNIQUE_ID_4 0x0044

/** Random number field 0 {un32 = Random} */
#define VE_REG_RANDOM_0 0x0050

/** Random number field 1 {un32 = Random} */
#define VE_REG_RANDOM_1 0x0051

/** Random number field 2 {un32 = Random} */
#define VE_REG_RANDOM_2 0x0052

/** Random number field 3 {un32 = Random} */
#define VE_REG_RANDOM_3 0x0053

/** Random number field 4 {un32 = Random} */
#define VE_REG_RANDOM_4 0x0054

/** Random number field 5 {un32 = Random} */
#define VE_REG_RANDOM_5 0x0055

/** Random number field 6 {un32 = Random} */
#define VE_REG_RANDOM_6 0x0056

/** Random number field 7 {un32 = Random} */
#define VE_REG_RANDOM_7 0x0057

/** Random number field 8 {un32 = Random} */
#define VE_REG_RANDOM_8 0x0058

/** Random number field 9 {un32 = Random} */
#define VE_REG_RANDOM_9 0x0059

/**
 * ProductId# {un8 = Identifier : un16 = Product Id, Note that the ve.direct mppt
 * chargers report this field incorrectly as an un16 with the product id in big-
 * endian notation : bits[1] = VictronEnergy Update (VUP) support : bits[7] =
 * reserved, 0x7F = reserved}
 */
#define VE_REG_PRODUCT_ID 0x0100

/** Revision# {un8 = Identifier : un16 = Revision : un8 = ECN} */
#define VE_REG_PRODUCT_REVISION 0x0101

/**
 * Firmware# {un8 = Identifier : un24 = Firmware Version, 0xFFFFFF = no firmware
 * present, Firmware version: 0x123456=v12.34.56}
 */
#define VE_REG_APP_VER 0x0102

/** Minimum Version# {un8 = Identifier : un24 = Firmware Version} */
#define VE_REG_APP_VER_MIN 0x0103

/**
 * GroupId# {un8 = Group Id, 10 = VE_GROUP_SOLAR_CHARGERS, 20 =
 * VE_GROUP_GRID_CHARGERS, 0xFE = VE_GROUP_RESERVED, 0xFF = VE_GROUP_NOT_SET}
 */
#define VE_REG_GROUP_ID 0x0104

/**
 * Identify {un8 = Identify, 0 = Off, 1 = On, Write a 1 to this register to
 * enable identify mode. Write a 0 to this register to disable identify mode and
 * return to normal operation.}
 */
#define VE_REG_INDENTIFY 0x010E

/**
 * udf version {un24 = udf version : bits[1] = udf active : bits[7] = reserved,
 * 0x7F = reserved}
 */
#define VE_REG_UDF_VERSION 0x0110

/** Uptime# {un32 = Uptime [1s]} */
#define VE_REG_UPTIME 0x0120

/** UDF.State */
#define VE_REG_UDF_STATE 0x0128

/** Stats RX HW overflow count {un32 = Counts} */
#define VE_REG_RX_HW_OVERFLOW_COUNT 0x0130

/** Stats RX SW overflow count {un32 = Counts} */
#define VE_REG_RX_SW_OVERFLOW_COUNT 0x0131

/** Stats Error Passive count {un32 = Counts} */
#define VE_REG_ERROR_PASSIVE_COUNT 0x0132

/** Stats Bus Off count {un32 = Counts} */
#define VE_REG_BUSOFF_COUNT 0x0133

/**
 * Device identification - capabilities1 {bits[1] = HAS_LOAD_OUTPUT, 0 = No, 1 =
 * Yes : bits[1] = HAS_ROTARY_ENCODER, 0 = No, 1 = Yes : bits[1] =
 * HAS_HISTORY_SUPPORT, 0 = No, 1 = Yes : bits[1] = HAS_BATTERYSAFE_MODE, 0 = No,
 * 1 = Yes : bits[1] = HAS_ADAPTIVE_MODE, 0 = No, 1 = Yes : bits[1] =
 * HAS_MANUAL_EQUALISE, 0 = No, 1 = Yes : bits[1] = HAS_AUTO_EQUALISE, 0 = No, 1
 * = Yes : bits[1] = HAS_STORAGE_MODE, 0 = No, 1 = Yes : bits[1] =
 * HAS_REMOTE_ONOFF, 0 = No, 1 = Yes : bits[1] = HAS_SOLAR_TIMER, 0 = No, 1 = Yes
 * : bits[1] = HAS_ALT_TX_FUNCTION, 0 = No, 1 = Yes : bits[1] =
 * HAS_USER_LOAD_SWITCH, 0 = No, 1 = Yes : bits[1] = HAS_LOAD_CURRENT, 0 = No, 1
 * = Yes : bits[1] = HAS_PANEL_CURRENT, 0 = No, 1 = Yes : bits[1] =
 * HAS_BMS_SUPPORT, 0 = No, 1 = Yes : bits[1] = HAS_HUB1_SUPPORT, 0 = No, 1 = Yes
 * : bits[1] = VE_REG_CAPABILITIES1_HAS_PARALLEL_SUPPORT, 0 = No, 1 = Yes :
 * bits[1] = VE_REG_CAPABILITIES1_HAS_ALARM_RELAY1, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_CAPABILITIES1_HAS_ALT_RX_FUNCTION, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_CAPABILITIES1_HAS_VIRTUAL_LOAD_OUTPUT, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_CAPABILITIES1_HAS_VIRTUAL_RELAY, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_CAPABILITIES1_HAS_DISPLAY, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_CAPABILITIES1_HAS_LOW_CURRENT_MODE, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_CAPABILITIES1_HAS_NIGHT_MODE, 0 = No, 1 = Yes : }
 */
#define VE_REG_CAPABILITIES1 0x0140

/**
 * Device identification - capabilities2 {bits[1] = HAS_NO_TEXT, 0 = No, 1 = Yes
 * : bits[1] = HAS_NO_ASYNC_HEX, 0 = No, 1 = Yes : bits[1] = HAS_NO_HEX, 0 = No,
 * 1 = Yes : }
 */
#define VE_REG_CAPABILITIES2 0x0141

/**
 * Device identification - capabilities3 {bits[1] = HAS_TUNNEL_SUPPORT, 0 = No, 1
 * = Yes : }
 */
#define VE_REG_CAPABILITIES3 0x0142

/** Device identification - capabilities4 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES4 0x0143

/** Device identification - capabilities5 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES5 0x0144

/** Device identification - capabilities6 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES6 0x0145

/** Device identification - capabilities7 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES7 0x0146

/** Device identification - capabilities8 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES8 0x0147

/** Device identification - capabilities9 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES9 0x0148

/** Device identification - capabilities10 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES10 0x0149

/** Device identification - capabilities11 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES11 0x014A

/** Device identification - capabilities12 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES12 0x014B

/** Device identification - capabilities13 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES13 0x014C

/** Device identification - capabilities14 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES14 0x014D

/** Device identification - capabilities15 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES15 0x014E

/** Device identification - capabilities16 {un32 = , 0 = reserved} */
#define VE_REG_CAPABILITIES16 0x014F

/** Device Mode {un8 = Mode} */
#define VE_REG_DEVICE_MODE 0x0200

/** Device State {un8 = State, Device state , @see N2kConverterState} */
#define VE_REG_DEVICE_STATE 0x0201

/**
 * Remote Control Used {bits[1] = ACIN1 current limit, 0 = Internal value, 1 =
 * Remote value : bits[1] = Remote On/Off, 0 = Internal value, 1 = Remote value :
 * bits[1] = ACIN2 current limit, 0 = Internal value, 1 = Remote value : bits[1]
 * = reserved 3, 0 = Internal value, 1 = Remote value : bits[1] = reserved 4, 0 =
 * Internal value, 1 = Remote value : bits[1] = reserved 5, 0 = Internal value, 1
 * = Remote value : bits[1] = reserved 6, 0 = Internal value, 1 = Remote value :
 * bits[1] = reserved 7, 0 = Internal value, 1 = Remote value : bits[1] = Sent
 * panel Leds, 0 = Internal value, 1 = Remote value : bits[1] = reserved 9, 0 =
 * Internal value, 1 = Remote value : bits[1] = reserved 10, 0 = Internal value,
 * 1 = Remote value : bits[1] = reserved 11, 0 = Internal value, 1 = Remote value
 * : bits[1] = reserved 12, 0 = Internal value, 1 = Remote value : bits[1] =
 * reserved 13, 0 = Internal value, 1 = Remote value : bits[1] = reserved 14, 0 =
 * Internal value, 1 = Remote value : bits[1] = reserved 15, 0 = Internal value,
 * 1 = Remote value : bits[1] = Sent cell voltage, 0 = Internal value, 1 = Remote
 * value : bits[1] = reserved 17, 0 = Internal value, 1 = Remote value : bits[1]
 * = reserved 18, 0 = Internal value, 1 = Remote value : bits[1] = reserved 19, 0
 * = Internal value, 1 = Remote value : bits[1] = reserved 20, 0 = Internal
 * value, 1 = Remote value : bits[1] = reserved 21, 0 = Internal value, 1 =
 * Remote value : bits[1] = reserved 22, 0 = Internal value, 1 = Remote value :
 * bits[1] = reserved 23, 0 = Internal value, 1 = Remote value : bits[1] =
 * reserved 24, 0 = Internal value, 1 = Remote value : bits[1] = reserved 25, 0 =
 * Internal value, 1 = Remote value : bits[1] = reserved 26, 0 = Internal value,
 * 1 = Remote value : bits[1] = reserved 27, 0 = Internal value, 1 = Remote value
 * : bits[1] = reserved 28, 0 = Internal value, 1 = Remote value : bits[1] =
 * reserved 29, 0 = Internal value, 1 = Remote value : bits[1] = reserved 30, 0 =
 * Internal value, 1 = Remote value : bits[1] = reserved 31, 0 = Internal value,
 * 1 = Remote value}
 */
#define VE_REG_REMOTE_CONTROL_USED 0x0202

/** AC IN Current Limit {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_CURRENT_LIMIT 0x0203

/** AC IN Active {un8 = Input, 0 = AC-IN1, 1 = AC-IN2} */
#define VE_REG_AC_IN_ACTIVE 0x0204

/** AC IN1 Current Limit {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_1_CURRENT_LIMIT 0x0210

/** AC IN1 Current Limit Min {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_1_CURRENT_LIMIT_MIN 0x0211

/** AC IN1 Current Limit Max {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_1_CURRENT_LIMIT_MAX 0x0212

/** AC IN1 Current Limit Internal {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_1_CURRENT_LIMIT_INTERNAL 0x0213

/**
 * AC IN1 Current Limit Remote {un16 = Limit [0.1A], 0 = use minimum current,
 * 0xFFFF = not available}
 */
#define VE_REG_AC_IN_1_CURRENT_LIMIT_REMOTE 0x0214

/** AC IN2 Current Limit {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_2_CURRENT_LIMIT 0x0220

/** AC IN2 Current Limit Min {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_2_CURRENT_LIMIT_MIN 0x0221

/** AC IN2 Current Limit Max {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_2_CURRENT_LIMIT_MAX 0x0222

/** AC IN2 Current Limit Internal {un16 = Limit [0.1A], 0xFFFF = Not Available} */
#define VE_REG_AC_IN_2_CURRENT_LIMIT_INTERNAL 0x0223

/**
 * AC IN2 Current Limit Remote {un16 = Limit [0.1A], 0 = use minimum current,
 * 0xFFFF = not available}
 */
#define VE_REG_AC_IN_2_CURRENT_LIMIT_REMOTE 0x0224

/** AC Voltage Setpoint {un16 = AC Voltage Setpoint [0.01V]} */
#define VE_REG_AC_OUT_VOLTAGE_SETPOINT 0x0230

/** Min AC Voltage Setpoint {un16 = Min AC Voltage Setpoint [0.01V]} */
#define VE_REG_AC_OUT_VOLTAGE_SETPOINT_MIN 0x0231

/** Max AC Voltage Setpoint {un16 = Max AC Voltage Setpoint [0.01V]} */
#define VE_REG_AC_OUT_VOLTAGE_SETPOINT_MAX 0x0232

/** Deepest discharge {sn32 = Deepest discharge [0.1Ah]} */
#define VE_REG_HIST_DEEPEST_DISCHARGE 0x0300

/** Last discharge {sn32 = Last discharge [0.1Ah]} */
#define VE_REG_HIST_LAST_DISCHARGE 0x0301

/** Average discharge {sn32 = Average discharge [0.1Ah]} */
#define VE_REG_HIST_AVERAGE_DISCHARGE 0x0302

/** Number of charge cycles {sn32 = Number of charge cycles} */
#define VE_REG_HIST_NR_OF_CHARGE_CYCLES 0x0303

/** Number of full discharges {sn32 = Number of full discharges} */
#define VE_REG_HIST_NR_OF_FULL_DISCHARGES 0x0304

/** Cumulative Ah {sn32 = Cumulative Ah drawn from the battery [0.1Ah]} */
#define VE_REG_HIST_CUMULATIVE_AH 0x0305

/** Minimum battery voltage {sn32 = Minimum battery voltage [0.01V]} */
#define VE_REG_HIST_MIN_VOLTAGE 0x0306

/** Maximum battery voltage {sn32 = Maximum battery voltage [0.01V]} */
#define VE_REG_HIST_MAX_VOLTAGE 0x0307

/** Time since full charge {sn32 = Number of seconds since last full charge [s]} */
#define VE_REG_HIST_SECS_SINCE_LAST_FULL_CHARGE 0x0308

/** Synchronizations {sn32 = Number of automatic synchronizations} */
#define VE_REG_HIST_NR_OF_AUTO_SYNCS 0x0309

/** Number of low voltage alarms {sn32 = Number of low voltage alarms} */
#define VE_REG_HIST_NR_OF_LOW_VOLTAGE_ALARMS 0x030A

/** Number of high voltage alarms {sn32 = Number of high voltage alarms} */
#define VE_REG_HIST_NR_OF_HIGH_VOLTAGE_ALARMS 0x030B

/**
 * Number of low auxilary voltage alarms {sn32 = Number of low auxilary voltage
 * alarms}
 */
#define VE_REG_HIST_NR_OF_LOW_VOLTAGE_2_ALARMS 0x030C

/**
 * Number of high auxilary voltage alarms {sn32 = Number of high auxilary voltage
 * alarms}
 */
#define VE_REG_HIST_NR_OF_HIGH_VOLTAGE_2_ALARMS 0x030D

/** Minimum auxilary voltage {sn32 = Minimum auxilary voltage [0.01V]} */
#define VE_REG_HIST_MIN_VOLTAGE_2 0x030E

/** Maximum auxilary voltage {sn32 = Maximum auxilary voltage [0.01V]} */
#define VE_REG_HIST_MAX_VOLTAGE_2 0x030F

/**
 * The amount of energy drawn from the source {un32 = The amount of energy drawn
 * from the source [0.01kWh]}
 */
#define VE_REG_HIST_KWH_OUT 0x0310

/**
 * The amount of energy put into the source {un32 = The amount of energy put into
 * the source [0.01kWh]}
 */
#define VE_REG_HIST_KWH_IN 0x0311

/** The maximum temperature {un16 = The maximum temperature [0.01K]} */
#define VE_REG_HIST_MAX_TEMPERATURE 0x0312

/** The minimum temperature {un16 = The minimum temperature [0.01K]} */
#define VE_REG_HIST_MIN_TEMPERATURE 0x0313

/** Warning reason {un16 = Warning reason} */
#define VE_REG_WARNING_REASON 0x031C

/** Alarm status {un8 = alarm flags, 0 = active, 1 = inactive} */
#define VE_REG_ALARM_STATUS 0x031D

/**
 * Alarm reason {un16 = Alarm reason, multiple flag can be or-ed together @remark
 * see @ref VE_REG_ALARM_REASON for bit mask}
 */
#define VE_REG_ALARM_REASON 0x031E

/** Acknowlegde alarm command (no data) */
#define VE_REG_ALARM_ACK 0x031F

/** Low voltage lower threshold */
#define VE_REG_ALARM_LOW_VOLTAGE_SET 0x0320

/** Low voltage upper threshold */
#define VE_REG_ALARM_LOW_VOLTAGE_CLEAR 0x0321

/** High voltage upper threshold */
#define VE_REG_ALARM_HIGH_VOLTAGE_SET 0x0322

/** High voltage lower threshold */
#define VE_REG_ALARM_HIGH_VOLTAGE_CLEAR 0x0323

/** Low auxilary voltage lower threshold */
#define VE_REG_ALARM_LOW_VOLTAGE_2_SET 0x0324

/** Low auxilary voltage upper threshold */
#define VE_REG_ALARM_LOW_VOLTAGE_2_CLEAR 0x0325

/** High auxilary voltage upper threshold */
#define VE_REG_ALARM_HIGH_VOLTAGE_2_SET 0x0326

/** High auxilary voltage lower threshold */
#define VE_REG_ALARM_HIGH_VOLTAGE_2_CLEAR 0x0327

/**
 * Low SOC lower threshold {un16 = Low SOC lower threshold [0.1%], @remark Lynx
 * Shunt VE.Can v1.08 and older: unit is 10%}
 */
#define VE_REG_ALARM_LOW_SOC_SET 0x0328

/**
 * Low SOC upper threshold {un16 = Low SOC upper threshold [0.1%], @remark Lynx
 * Shunt VE.Can v1.08 and older: unit is 10%}
 */
#define VE_REG_ALARM_LOW_SOC_CLEAR 0x0329

/**
 * Low battery temperature lower threshold {un16 = Low battery temperature lower
 * threshold [0.01K]}
 */
#define VE_REG_ALARM_LOW_BAT_TEMP_SET 0x032A

/**
 * Low battery temperature upper threshold {un16 = Low battery temperature upper
 * threshold [0.01K]}
 */
#define VE_REG_ALARM_LOW_BAT_TEMP_CLEAR 0x032B

/**
 * High battery temperature upper threshold {un16 = High battery temperature
 * upper threshold [0.01K]}
 */
#define VE_REG_ALARM_HIGH_BAT_TEMP_SET 0x032C

/**
 * High battery temperature lower threshold {un16 = High battery temperature
 * lower threshold [0.01K]}
 */
#define VE_REG_ALARM_HIGH_BAT_TEMP_CLEAR 0x032D

/**
 * High internal temperature alarm upper threshold {un16 = High internal
 * temperature alarm upper threshold [0.01K]}
 */
#define VE_REG_ALARM_HIGH_INT_TEMP_SET 0x032E

/**
 * High internal temperature alarm lower threshold {un16 = High internal
 * temperature alarm lower threshold [0.01K]}
 */
#define VE_REG_ALARM_HIGH_INT_TEMP_CLEAR 0x032F

/**
 * Fuse blown alarm enable {un8 = Fuse blown alarm enable, 0 = enabled, 1 =
 * disabled}
 */
#define VE_REG_ALARM_FUSE_BLOWN 0x0330

/** Mid voltage alarm set {un16 = Mid voltage alarm set [0.1%]} */
#define VE_REG_ALARM_MID_VOLTAGE_SET 0x0331

/** Mid voltage alarm clear {un16 = Mid voltage alarm clear [0.1%]} */
#define VE_REG_ALARM_MID_VOLTAGE_CLEAR 0x0332

/** Relay invert. {un8 = relay invert, 0 = not-invert, 1 = invert} */
#define VE_REG_RELAY_INVERT 0x034D

/** Relay control {un8 = Relay control} */
#define VE_REG_RELAY_CONTROL 0x034E

/**
 * Relay Mode {un8 = Relay Mode, 0x00 = Alarm, 0x01 = Charger mode, 0x02 = Remote
 * control, 0x03 = Always open}
 */
#define VE_REG_RELAY_MODE 0x034F

/** Relay Low Voltage Set */
#define VE_REG_RELAY_LOW_VOLTAGE_SET 0x0350

/** Relay Low Voltage Clear */
#define VE_REG_RELAY_LOW_VOLTAGE_CLEAR 0x0351

/** High voltage upper threshold */
#define VE_REG_RELAY_HIGH_VOLTAGE_SET 0x0352

/** Relay High Voltage Clear */
#define VE_REG_RELAY_HIGH_VOLTAGE_CLEAR 0x0353

/** Relay Low Voltage 2 Set */
#define VE_REG_RELAY_LOW_VOLTAGE_2_SET 0x0354

/** Relay Low Voltage 2 Clear */
#define VE_REG_RELAY_LOW_VOLTAGE_2_CLEAR 0x0355

/** Relay High Voltage 2 Set */
#define VE_REG_RELAY_HIGH_VOLTAGE_2_SET 0x0356

/** Relay High Voltage 2 Clear */
#define VE_REG_RELAY_HIGH_VOLTAGE_2_CLEAR 0x0357

/** Low SOC lower threshold {un16 = Low SOC lower threshold [0.1%]} */
#define VE_REG_RELAY_LOW_SOC_SET 0x0358

/** Low SOC upper threshold {un16 = Low SOC upper threshold [0.1%]} */
#define VE_REG_RELAY_LOW_SOC_CLEAR 0x0359

/**
 * Low battery temperature lower threshold {un16 = Low battery temperature lower
 * threshold [0.01K]}
 */
#define VE_REG_RELAY_LOW_BAT_TEMP_SET 0x035A

/**
 * Low battery temperature upper threshold {un16 = Low battery temperature upper
 * threshold [0.01K]}
 */
#define VE_REG_RELAY_LOW_BAT_TEMP_CLEAR 0x035B

/**
 * High battery temperature upper threshold {un16 = High battery temperature
 * upper threshold [0.01K]}
 */
#define VE_REG_RELAY_HIGH_BAT_TEMP_SET 0x035C

/**
 * High battery temperature lower threshold {un16 = High battery temperature
 * lower threshold [0.01K]}
 */
#define VE_REG_RELAY_HIGH_BAT_TEMP_CLEAR 0x035D

/**
 * High internal temperature relay upper threshold {un16 = High internal
 * temperature relay upper threshold [0.01K]}
 */
#define VE_REG_RELAY_HIGH_INT_TEMP_SET 0x035E

/**
 * High internal temperature relay lower threshold {un16 = High internal
 * temperature relay lower threshold [0.01K]}
 */
#define VE_REG_RELAY_HIGH_INT_TEMP_CLEAR 0x035F

/**
 * Enable closing the relay when the fuse is blown {un8 = Enable closing the
 * relay when the fuse is blown, 0 = enabled, 1 = disabled}
 */
#define VE_REG_RELAY_FUSE_BLOWN 0x0360

/** Mid voltage relay set {un16 = Mid voltage relay set [0.1%]} */
#define VE_REG_RELAY_MID_VOLTAGE_SET 0x0361

/** Mid voltage relay clear {un16 = Mid voltage relay clear [0.1%]} */
#define VE_REG_RELAY_MID_VOLTAGE_CLEAR 0x0362

/** Lynx Ion battery flags . {un32 = Lynx Ion battery flags .} */
#define VE_REG_LYNX_ION_FLAGS 0x0370

/** Lynx Ion BMS state {un8 = Lynx Ion BMS state} */
#define VE_REG_LYNX_ION_BMS_STATE 0x0371

/**
 * Lynx Ion BMS error flags . Note that this is a value, not a bit mask. {un32 =
 * Lynx Ion BMS error flags . Note that this is a value, not a bit mask.}
 */
#define VE_REG_LYNX_ION_BMS_ERROR_FLAGS 0x0372

/**
 * Number of batteries and number of cells per battery {un8 = Number of batteries
 * and number of cells per battery, nrOfBatteries, un8 cellsPerBattery}
 */
#define VE_REG_BATTERY_CONFIGURATION 0x0380

/**
 * Voltages of cell n of battery m . {un8 = n : un8 = m : un16 = Voltages of cell
 * n of battery m . [0.01V]}
 */
#define VE_REG_BATTERY_CELL_VOLTAGE 0x0381

/**
 * The mid-point voltage of a battery bank {un16 = The mid-point voltage of a
 * battery bank [0.01V], 0xFFFF = not available}
 */
#define VE_REG_BATTERY_MID_POINT_VOLTAGE 0x0382

/**
 * The mid-point deviation relative to the expected {sn16 = The mid-point
 * deviation relative to the expected [0.1%], 0x7FFF = not available}
 */
#define VE_REG_BATTERY_MID_POINT_DEVIATION 0x0383

/**
 * Maximum/minimum cell voltage (involatile) (un16 = min voltage (0.01V) : un16 =
 * max voltage (0.01V).
 */
#define VE_REG_BATTERY_CELL_VOLTAGE_MIN_MAX 0x0384

/** Backlight always on {un8 = Backlight always on, 0 = off, 1 = on, 2 = auto} */
#define VE_REG_BACKLIGHT_ALWAYS_ON 0x0400

/** Backlight intensity {un8 = intensity} */
#define VE_REG_BACKLIGHT_INTENSITY 0x0401

/** Display scroll speed {un8 = scroll speed} */
#define VE_REG_DISPLAY_SCROLL_SPEED 0x0402

/** Lock setup {un8 = Lock setup, 0 = unlocked, 1 = locked} */
#define VE_REG_DISPLAY_SETUP_LOCK 0x0403

/** Temperature unit {un8 = Temperature unit, 0 = Celcius, 1 = Fahrenheit} */
#define VE_REG_DISPLAY_TEMPERATURE_UNIT 0x0404

/**
 * Sound buzzer when alarm active {un8 = Sound buzzer when alarm active, 0 = off,
 * 1 = on}
 */
#define VE_REG_ALARM_BUZZER 0x0405

/**
 * BROKEN: Statistics page Peak Power Pack {un8 = version : un32 = sequence nr :
 * un8 = deep discharge events : un8 = under-voltage events : un16 = over-voltage
 * events : un8 = over-temperature events : un8 = short-circuit events : un16 =
 * mover output activations : un32 = mover time : un32 = sub-zero time : un16 =
 * charge cycles : un16 = charge cycles at high temperature : un16 = discharges
 * at high temperature : stringFixed[7] = reserved, =0xFF}
 */
#define VE_REG_STATS_PEAK_POWER_PACK 0x0500

/** Time to go {un16 = Time to go [1minutes], 0xFFFF = not available} */
#define VE_REG_TTG 0x0FFE

/** State of charge {un16 = SOC [0.01%]} */
#define VE_REG_SOC 0x0FFF

/** Battery capacity {un16 = Battery capacity [Ah]} */
#define VE_REG_BATTERY_CAPACITY 0x1000

/** Charged voltage {un16 = Charged voltage [0.1V]} */
#define VE_REG_CHARGED_VOLTAGE 0x1001

/** Charged current {un16 = Charged current [0.1%]} */
#define VE_REG_CHARGED_CURRENT 0x1002

/** Charged detection time. {un16 = Charged detection time. [1minutes]} */
#define VE_REG_CHARGE_DETECTION_TIME 0x1003

/** Charge efficiency {un16 = Charge efficiency [1%]} */
#define VE_REG_CHARGE_EFFICIENCY 0x1004

/** Peukert coefficient {un16 = Peukert coefficient [0.01]} */
#define VE_REG_PEUKERT_COEFFICIENT 0x1005

/** Current threshold {un16 = Current threshold [0.01A]} */
#define VE_REG_CURRENT_THRESHOLD 0x1006

/** TTG Delta T {un16 = TTG Delta T [1minutes]} */
#define VE_REG_TTG_DELTA_T 0x1007

/** Low SOC (Discharge floor) {un16 = Low SOC (Discharge floor) [0.1%]} */
#define VE_REG_LOW_SOC 0x1008

/**
 * Low SOC Clear (Relay Low Soc Clear) {un16 = Low SOC Clear (Relay Low Soc
 * Clear) [0.1%]}
 */
#define VE_REG_LOW_SOC_CLEAR 0x1009

/**
 * Relay Min Enabled {un16 = Relay Min Enabled [1minutes], 0xFFFF = Not
 * Available, The minimal number of minutes the relay in enabled}
 */
#define VE_REG_RELAY_MIN_ENABLED 0x100A

/**
 * Relay Disable Delay {un16 = Relay Disable Delay [1minutes], 0xFFFF = Not
 * Available, The number of minutes the relay remains enabled after the relay
 * condition is false.}
 */
#define VE_REG_RELAY_DISABLE_DELAY 0x100B

/** Zero current command */
#define VE_REG_ZERO_CURRENT 0x1029

/** Synchronize monitor command */
#define VE_REG_SYNCHRONIZE 0x102C

/** Clear history command */
#define VE_REG_CLEAR_HISTORY 0x1030

/**
 * Transmit history data (normally history data is sent on change only, write to
 * this register to request a transmission).
 *       Use vregs @ref VE_REG_HISTORY_TOTAL, @ref VE_REG_HISTORY_DAY00 .. @ref
 * VE_REG_HISTORY_DAY30 instead
 */
#define VE_REG_TRANSMIT_HISTORY 0x1031

/** User current zero in counts {sn16 = User current zero in counts} */
#define VE_REG_CURRENT_OFFSET 0x1034

/** Link Algorithm {un8 = Link Algorithm} */
#define VE_REG_LINK_ALGORITHM 0x2000

/**
 * Link VSet {un16 = Link VSet [0.01V], 0xFFFF = Not Available, Charger link,
 * voltage set-point }
 */
#define VE_REG_LINK_VSET 0x2001

/**
 * Link VSense {un16 = Link VSense [0.01V], 0xFFFF = Not Available, Charger link,
 * battery sense voltage }
 */
#define VE_REG_LINK_VSENSE 0x2002

/** Link TSense {sn16 = Temperature [0.01°C], 0x7FFF = Not Available} */
#define VE_REG_LINK_TSENSE 0x2003

/**
 * Link Command {un8 = Commmand, 0x01 = VE_REG_COMMAND_START_EQUALISE, 0x02 =
 * VE_REG_COMMAND_STOP_EQUALISE, 0x03 = VE_REG_COMMAND_GUI_SYNC, 0x04 =
 * VE_REG_COMMAND_DAY_SYNC, Charger link, command channel from slaves to master}
 */
#define VE_REG_LINK_COMMAND 0x2004

/**
 * Link Switch Bank Status {bits[1] = Switch 1, 0 = Off, 1 = On : bits[1] =
 * Switch 2, 0 = Off, 1 = On : bits[1] = Switch 3, 0 = Off, 1 = On : bits[1] =
 * Switch 4, 0 = Off, 1 = On : bits[1] = Switch 5, 0 = Off, 1 = On : bits[1] =
 * Switch 6, 0 = Off, 1 = On : bits[1] = Switch 7, 0 = Off, 1 = On : bits[1] =
 * Switch 8, 0 = Off, 1 = On : bits[1] = Switch 9, 0 = Off, 1 = On : bits[1] =
 * Switch 10, 0 = Off, 1 = On : bits[1] = Switch 11, 0 = Off, 1 = On : bits[1] =
 * Switch 12, 0 = Off, 1 = On : bits[1] = Switch 13, 0 = Off, 1 = On : bits[1] =
 * Switch 14, 0 = Off, 1 = On : bits[1] = Switch 15, 0 = Off, 1 = On : bits[1] =
 * Switch 16, 0 = Off, 1 = On : bits[1] = Switch 17, 0 = Off, 1 = On : bits[1] =
 * Switch 18, 0 = Off, 1 = On : bits[1] = Switch 19, 0 = Off, 1 = On : bits[1] =
 * Switch 20, 0 = Off, 1 = On : bits[1] = Switch 21, 0 = Off, 1 = On : bits[1] =
 * Switch 22, 0 = Off, 1 = On : bits[1] = Switch 23, 0 = Off, 1 = On : bits[1] =
 * Switch 24, 0 = Off, 1 = On : bits[1] = Switch 25, 0 = Off, 1 = On : bits[1] =
 * Switch 26, 0 = Off, 1 = On : bits[1] = Switch 27, 0 = Off, 1 = On : bits[1] =
 * Switch 28, 0 = Off, 1 = On}
 */
#define VE_REG_LINK_BINARY_SWITCH_BANK_STATUS 0x2005

/**
 * Link Switch Bank Mask {bits[1] = Switch 1, 0 = Unused, 1 = Used : bits[1] =
 * Switch 2, 0 = Unused, 1 = Used : bits[1] = Switch 3, 0 = Unused, 1 = Used :
 * bits[1] = Switch 4, 0 = Unused, 1 = Used : bits[1] = Switch 5, 0 = Unused, 1 =
 * Used : bits[1] = Switch 6, 0 = Unused, 1 = Used : bits[1] = Switch 7, 0 =
 * Unused, 1 = Used : bits[1] = Switch 8, 0 = Unused, 1 = Used : bits[1] = Switch
 * 9, 0 = Unused, 1 = Used : bits[1] = Switch 10, 0 = Unused, 1 = Used : bits[1]
 * = Switch 11, 0 = Unused, 1 = Used : bits[1] = Switch 12, 0 = Unused, 1 = Used
 * : bits[1] = Switch 13, 0 = Unused, 1 = Used : bits[1] = Switch 14, 0 = Unused,
 * 1 = Used : bits[1] = Switch 15, 0 = Unused, 1 = Used : bits[1] = Switch 16, 0
 * = Unused, 1 = Used : bits[1] = Switch 17, 0 = Unused, 1 = Used : bits[1] =
 * Switch 18, 0 = Unused, 1 = Used : bits[1] = Switch 19, 0 = Unused, 1 = Used :
 * bits[1] = Switch 20, 0 = Unused, 1 = Used : bits[1] = Switch 21, 0 = Unused, 1
 * = Used : bits[1] = Switch 22, 0 = Unused, 1 = Used : bits[1] = Switch 23, 0 =
 * Unused, 1 = Used : bits[1] = Switch 24, 0 = Unused, 1 = Used : bits[1] =
 * Switch 25, 0 = Unused, 1 = Used : bits[1] = Switch 26, 0 = Unused, 1 = Used :
 * bits[1] = Switch 27, 0 = Unused, 1 = Used : bits[1] = Switch 28, 0 = Unused, 1
 * = Used}
 */
#define VE_REG_LINK_BINARY_SWITCH_BANK_MASK 0x2006

/** Link Elapsed Time {un32 = Time [0.001s]} */
#define VE_REG_LINK_ELAPSED_TIME 0x2007

/** Link Absorption Time {un16 = Time [0.01hours]} */
#define VE_REG_LINK_ABSORPTION_TIME 0x2008

/**
 * Link Network Mode {bits[1] = VE_REG_NETWORK_MODE_NETWORKED, 0 = No, 1 = Yes :
 * bits[1] = VE_REG_NETWORK_MODE_REMOTE_CHARGE, 0 = No, 1 = Yes, remote algoritm
 * : bits[1] = VE_REG_NETWORK_MODE_REMOTE_HUB1, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_NETWORK_MODE_REMOTE_BMS, 0 = No, 1 = Yes, remote bms puts a ve.direct
 * device in remote controlled mode. : bits[1] =
 * VE_REG_NETWORK_MODE_GROUP_MASTER, 0 = No, 1 = Yes : bits[1] =
 * VE_REG_NETWORK_MODE_INSTANCE_MASTER, 0 = No, 1 = Yes : bits[1] = reserved 6, 0
 * = No, 1 = Yes : bits[1] = reserved 7, 0 = No, 1 = Yes}
 */
#define VE_REG_LINK_NETWORK_MODE 0x200E

/**
 * Link Device Network {bits[1] = VE_REG_NETWORK_STATUS_GROUP_MASTER, 0 = No, 1 =
 * Yes : bits[1] = VE_REG_NETWORK_STATUS_INSTANCE_MASTER, 0 = No, 1 = Yes :
 * bits[1] = VE_REG_NETWORK_STATUS_STANDALONE, 0 = No, 1 = Yes : bits[1] =
 * reserved 3, 0 = No, 1 = Yes : bits[1] = reserved 4, 0 = No, 1 = Yes : bits[1]
 * = reserved 5, 0 = No, 1 = Yes : bits[1] = reserved 6, 0 = No, 1 = Yes :
 * bits[1] = reserved 7, 0 = No, 1 = Yes}
 */
#define VE_REG_LINK_NETWORK_STATUS 0x200F

/**
 * Link AC Input Current Maximum {un16 = Link AC Input Current Maximum [0.1A],
 * 0xFFFF = Not Available}
 */
#define VE_REG_LINK_AC_INPUT_MAX_CURRENT 0x2010

/**
 * Link AC Input Current Limit {un16 = Link AC Input Current Limit [0.1A], 0xFFFF
 * = Not Available}
 */
#define VE_REG_LINK_AC_INPUT_CURRENT_LIMIT 0x2011

/**
 * Link AC Input Current {un16 = Link AC Input Current [0.1A], 0xFFFF = Not
 * Available}
 */
#define VE_REG_LINK_AC_INPUT_CURRENT 0x2012

/**
 * Link Charge Current Percentage {un8 = Percentage [1%], 0xFF = Not Available,
 * valid range 0 till 100}
 */
#define VE_REG_LINK_CHARGE_CURRENT_PERCENTAGE 0x2014

/**
 * Link Charge Current Limit {un16 = Link Charge Current Limit [0.1A], 0xFFFF =
 * Not Available}
 */
#define VE_REG_LINK_CHARGE_CURRENT_LIMIT 0x2015

/**
 * Link Charge Voltage Setpoint {un16 = Link Charge Voltage Setpoint [0.01V],
 * 0xFFFF = Not Available}
 */
#define VE_REG_LINK_CHARGE_VOLTAGE_SETPOINT 0x2016

/**
 * Link System Yield {un32 = Link System Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available}
 */
#define VE_REG_LINK_SYSTEM_YIELD 0x2020

/** Link User Yield {un32 = Link User Yield [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_LINK_USER_YIELD 0x2021

/**
 * Link Yield Today {un32 = Link Yield Today [0.01kWh], 0xFFFFFFFF = Not
 * Available}
 */
#define VE_REG_LINK_TODAY_YIELD 0x2022

/**
 * Link Maximum Power Today {un16 = Link Maximum Power Today [1W], 0xFFFF = Not
 * Available}
 */
#define VE_REG_LINK_TODAY_PMAX 0x2023

/**
 * Link Yield Yesterday {un32 = Link Yield Yesterday [0.01kWh], 0xFFFFFFFF = Not
 * Available}
 */
#define VE_REG_LINK_YESTERDAY_YIELD 0x2024

/**
 * Link Maximum Power Yesterday {un16 = Link Maximum Power Yesterday [1W], 0xFFFF
 * = Not Available}
 */
#define VE_REG_LINK_YESTERDAY_PMAX 0x2025

/**
 * Link Actual Power {un32 = Link Actual Power [0.01W], 0xFFFFFFFF = Not
 * Available}
 */
#define VE_REG_LINK_ACTUAL_POWER 0x2026

/**
 * Link RTC Solar {un8 = Link RTC Solar, 0x00 = Dark, 0x01 = Light, 0xFF = Not
 * Available}
 */
#define VE_REG_LINK_RTC_SOLAR 0x2030

/**
 * Link RTC Time {un16 = Link RTC Time [1minutes], 0xFFFF = Not Available, valid
 * range 0..1440 (starting at midnight)}
 */
#define VE_REG_LINK_RTC_TIME 0x2031

/** Link SYNC Timebase (debug) {un32 = T} */
#define VE_REG_LINK_SYNC_TIMEBASE 0x2032

/** Link SYNC Period (debug) {un32 = T} */
#define VE_REG_LINK_SYNC_PERIOD 0x2033

/** Link SYNC Phase (debug) {sn32 = T} */
#define VE_REG_LINK_SYNC_PHASE 0x2034

/** Link CHECK Timebase (debug) {un32 = T} */
#define VE_REG_LINK_CHECK_TIMEBASE 0x2035

/** Link CHECK Period (debug) {un32 = T} */
#define VE_REG_LINK_CHECK_PERIOD 0x2036

/** Link CHECK Phase (debug) {sn32 = T} */
#define VE_REG_LINK_CHECK_PHASE 0x2037

/**
 * Multi/Phoenix Inverter voltage at (first or main) AC output {sn16 =
 * Multi/Phoenix Inverter voltage at (first or main) AC output [0.01V]}
 */
#define VE_REG_AC_OUT_VOLTAGE 0x2200

/**
 * Multi/Phoenix Inverter current (through first or main) AC output. {sn16 =
 * Multi/Phoenix Inverter current (through first or main) AC output. [0.1A]}
 */
#define VE_REG_AC_OUT_CURRENT 0x2201

/** Shutdown On Low Voltage {un16 = Shutdown On Low Voltage [0.01V]} */
#define VE_REG_SHUTDOWN_LOW_VOLTAGE_SET 0x2210

/** Balancer cell voltage low set {un16 = Balancer cell voltage low set [0.001V]} */
#define VE_REG_BALANCER_CELL_VOLTAGE_LOW_SET 0xEA00

/**
 * Balancer cell voltage low clear {un16 = Balancer cell voltage low clear
 * [0.001V]}
 */
#define VE_REG_BALANCER_CELL_VOLTAGE_LOW_CLEAR 0xEA01

/**
 * Balancer cell voltage high set {un16 = Balancer cell voltage high set
 * [0.001V]}
 */
#define VE_REG_BALANCER_CELL_VOLTAGE_HIGH_SET 0xEA02

/**
 * Balancer cell voltage high clear {un16 = Balancer cell voltage high clear
 * [0.001V]}
 */
#define VE_REG_BALANCER_CELL_VOLTAGE_HIGH_CLEAR 0xEA03

/**
 * Balancer cell voltage valid detect low {un16 = Balancer cell voltage valid
 * detect low [0.001V]}
 */
#define VE_REG_BALANCER_VOLTAGE_VALID_DETECT_LOW 0xEA04

/**
 * Balancer cell voltage valid detect high {un16 = Balancer cell voltage valid
 * detect high [0.001V]}
 */
#define VE_REG_BALANCER_VOLTAGE_VALID_DETECT_HIGH 0xEA05

/**
 * Balancer cell voltage keep balancing {un16 = Balancer cell voltage keep
 * balancing [0.001V]}
 */
#define VE_REG_BALANCER_CELL_VOLTAGE_KEEP_BALANCING 0xEA06

/**
 * Balancer maximum balance current {un16 = Balancer maximum balance current
 * [0.001A]}
 */
#define VE_REG_BALANCER_MAXIMUM_BALANCE_CURRENT 0xEA07

/**
 * Balancer cell voltage switch off threshold {un16 = Balancer cell voltage
 * switch off threshold [0.001V]}
 */
#define VE_REG_BALANCER_CELL_VOLTAGE_SWITCH_OFF_THRESHOLD 0xEA08

/**
 * Balancer cell voltage switch on threshold {un16 = Balancer cell voltage switch
 * on threshold [0.001V]}
 */
#define VE_REG_BALANCER_CELL_VOLTAGE_SWITCH_ON_THRESHOLD 0xEA09

/**
 * Balancer keep balancing current {un16 = Balancer keep balancing current
 * [0.001A]}
 */
#define VE_REG_BALANCER_KEEP_BALANCING_CURRENT 0xEA0A

/**
 * Balancer temperature low level {sn16 = Balancer temperature low level
 * [0.01°C]}
 */
#define VE_REG_BALANCER_TEMPERATURE_LOW_LEVEL 0xEA0B

/**
 * Balancer temperature high level {sn16 = Balancer temperature high level
 * [0.01°C]}
 */
#define VE_REG_BALANCER_TEMPERATURE_HIGH_LEVEL 0xEA0C

/**
 * Balancer cell voltage activate internal load {un16 = Balancer cell voltage
 * activate internal load [0.001V]}
 */
#define VE_REG_BALANCER_CELL_VOLTAGE_ACTIVATE_INTERNAL_LOAD 0xEA0D

/** Tank Capacity {un32 = Tank Capacity [0.0001m3]} */
#define VE_REG_TANK_CAPACITY 0xED4D

/**
 * Tank type {un8 = Tank type, type: 0=fuel, 1=fresh water, 2=waste water, 3=live
 * well, 4=oil, 5=black water (sewage) NMEA2000 equivalent: DD208 Fluid Type as
 * found in PGN 127505 (v2.000). Note that field this is 4-bits wide. New types
 * should be added from the top, taking the NMEA 2000 reserved values (6-15) in
 * account.@remark New types should be added from the top, taking the NMEA 2000
 * reserved values (6-15) in account.}
 */
#define VE_REG_TANK_TYPE 0xED4E

/** Tank level {un16 = level [0.1%]} */
#define VE_REG_TANK_LEVEL 0xED4F

/**
 * actual load status channel 2. @remark status: 0=off, 1=on see @ref
 * VE_REG_DC_OUTPUT_STATUS {un8 = actual load status channel 2. @remark status:
 * 0=off, 1=on see @ref VE_REG_DC_OUTPUT_STATUS}
 */
#define VE_REG_DC_OUTPUT2_STATUS 0xED58

/**
 * actual load voltage channel 2 see @ref VE_REG_DC_OUTPUT_VOLTAGE. {un16 =
 * actual load voltage channel 2 see @ref VE_REG_DC_OUTPUT_VOLTAGE. [0.01V]}
 */
#define VE_REG_DC_OUTPUT2_VOLTAGE 0xED59

/**
 * actual load power channel 2 see @ref VE_REG_DC_OUTPUT_POWER. {un16 = actual
 * load power channel 2 see @ref VE_REG_DC_OUTPUT_POWER. [1W]}
 */
#define VE_REG_DC_OUTPUT2_POWER 0xED5A

/**
 * Load output specific parameters - load control channel 2 see @ref
 * VE_REG_DC_OUTPUT_CONTROL section for possible values see @ref
 * VE_REG_DC_OUTPUT_CONTROL. {un8 = Load output specific parameters - load
 * control channel 2 see @ref VE_REG_DC_OUTPUT_CONTROL section for possible
 * values see @ref VE_REG_DC_OUTPUT_CONTROL.}
 */
#define VE_REG_DC_OUTPUT2_CONTROL 0xED5B

/**
 * Load output offset voltage - load battery life algorithm channel 2 see @ref
 * VE_REG_DC_OUTPUT_OFFSET_VOLTAGE. {un8 = Load output offset voltage - load
 * battery life algorithm channel 2 see @ref VE_REG_DC_OUTPUT_OFFSET_VOLTAGE.
 * [0.01V]}
 */
#define VE_REG_DC_OUTPUT2_OFFSET_VOLTAGE 0xED5C

/**
 * Load output specific parameters - actual load current channel 2 see @ref
 * VE_REG_DC_OUTPUT_CURRENT. {un16 = Load output specific parameters - actual
 * load current channel 2 see @ref VE_REG_DC_OUTPUT_CURRENT. [0.1A]}
 */
#define VE_REG_DC_OUTPUT2_CURRENT 0xED5D

/**
 * Load output specific parameters - load current limit channel 2 see @ref
 * VE_REG_DC_OUTPUT_CURRENT_LIMIT. {un16 = Load output specific parameters - load
 * current limit channel 2 see @ref VE_REG_DC_OUTPUT_CURRENT_LIMIT. [0.1A]}
 */
#define VE_REG_DC_OUTPUT2_CURRENT_LIMIT 0xED5E

/**
 * Load output specific parameters - maximum allowed load current channel 2 see
 * VE_REG_DC_OUTPUT_MAeX_CURRENT. {un16 = Load output specific parameters -
 * maximum allowed load current channel 2 see VE_REG_DC_OUTPUT_MAeX_CURRENT.
 * [0.1A]}
 */
#define VE_REG_DC_OUTPUT2_MAX_CURRENT 0xED5F

/**
 * DC Channel 3 Voltage {sn16 = DC Channel 3 Voltage [0.01V], 0x7FFF = Not
 * Available}
 */
#define VE_REG_DC_CHANNEL3_VOLTAGE 0xED6D

/** DC Channel 3 Power {sn16 = DC Channel 3 Power [1W], 0x7FFF = Not Available} */
#define VE_REG_DC_CHANNEL3_POWER 0xED6E

/**
 * DC Channel 3 Current {sn16 = DC Channel 3 Current [0.1A], 0x7FFF = Not
 * Available}
 */
#define VE_REG_DC_CHANNEL3_CURRENT 0xED6F

/**
 * DC Channel 2 Voltage {sn16 = DC Channel 2 Voltage [0.01V], 0x7FFF = Not
 * Available}
 */
#define VE_REG_DC_CHANNEL2_VOLTAGE 0xED7D

/** DC Channel 2 Power {sn16 = DC Channel 2 Power [1W], 0x7FFF = Not Available} */
#define VE_REG_DC_CHANNEL2_POWER 0xED7E

/**
 * DC Channel 2 Current {sn16 = DC Channel 2 Current [0.1A], 0x7FFF = Not
 * Available}
 */
#define VE_REG_DC_CHANNEL2_CURRENT 0xED7F

/**
 * DC Channel 1 Voltage {sn16 = DC Channel 1 Voltage [0.01V], 0x7FFF = Not
 * Available}
 */
#define VE_REG_DC_CHANNEL1_VOLTAGE 0xED8D

/** DC Channel 1 Power {sn16 = DC Channel 1 Power [1W], 0x7FFF = Not Available} */
#define VE_REG_DC_CHANNEL1_POWER 0xED8E

/**
 * DC Channel 1 Current {sn16 = DC Channel 1 Current [0.1A], 0x7FFF = Not
 * Available}
 */
#define VE_REG_DC_CHANNEL1_CURRENT 0xED8F

/** RTC Ton time (debug) {un16 = RTC Ton time (debug), 0xFFFF = Not Available} */
#define VE_REG_LINK_RTC_TON_TIME 0xED92

/** RTC Toff time (debug) {un16 = RTC Toff time (debug), 0xFFFF = Not Available} */
#define VE_REG_LINK_RTC_TOFF_TIME 0xED93

/**
 * RTC Toff expected (debug) {un16 = RTC Toff expected (debug), 0xFFFF = Not
 * Available}
 */
#define VE_REG_LINK_RTC_TOFF_EXPECTED 0xED94

/**
 * RTC Ton expected (debug) {un16 = RTC Ton expected (debug), 0xFFFF = Not
 * Available}
 */
#define VE_REG_LINK_RTC_TON_EXPECTED 0xED95

/**
 * Ve.direct port rx function {un8 = Ve.direct port rx function, 0x00 = Remote
 * on/off, 0x01 = Load output config}
 */
#define VE_REG_VEDIRECT_PORT_RX_FUNCTION 0xED98

/**
 * DC Output Panel voltage day {un16 = DC Output Panel voltage day [0.01V],
 * 0xFFFF = Not Available, Charger load output specific parameters - panel day
 * voltage detection level}
 */
#define VE_REG_DC_OUTPUT_PANEL_VOLTAGE_DAY 0xED99

/**
 * DC Output Panel voltage night {un16 = DC Output Panel voltage night [0.01V],
 * 0xFFFF = Not Available, Charger load output specific parameters - panel night
 * voltage detection level}
 */
#define VE_REG_DC_OUTPUT_PANEL_VOLTAGE_NIGHT 0xED9A

/**
 * DC Output Lighting dim speed {un8 = DC Output Lighting dim speed, @remark dim:
 * valid range 0 till 100, 0=instantaneous change, x=1% change per x seconds,
 * e.g. 9 takes 15 minutes to dim from 0..100%}
 */
#define VE_REG_DC_OUTPUT_LIGHTING_DIM_SPEED 0xED9B

/**
 * DC Output Switch Low Level {un16 = DC Output Switch Low Level [0.01V], 0xFFFF
 * = Not Available, Charger load output specific parameters - user defined switch
 * low voltage level}
 */
#define VE_REG_DC_OUTPUT_SWITCH_LOW_LEVEL 0xED9C

/**
 * DC Output Switch High Level {un16 = DC Output Switch High Level [0.01V],
 * 0xFFFF = Not Available, Charger load output specific parameters - user defined
 * switch high voltage level}
 */
#define VE_REG_DC_OUTPUT_SWITCH_HIGH_LEVEL 0xED9D

/**
 * Ve.direct port tx function {un8 = Ve.direct port tx function, 0x00 = Ve.direct
 * communication, 0x01 = 0.01kWh pulses, 0x02 = Lighting PWM (normal), 0x03 =
 * Lighting PWM (inverted), Special function selection for the TX pin on the
 * ve.direct port see VE_REG_VEDIRECT_PORT_TX_FUNCTION section for possible
 * values.}
 */
#define VE_REG_VEDIRECT_PORT_TX_FUNCTION 0xED9E

/** Physical selection {un8 = Physical selection, 0 = Off, 1 = On} */
#define VE_REG_CAN_SELECT 0xED9F

/**
 * DC Output Lighting event 0 {sn16 = Time offset [1minutes] : un8 = Event code,
 * 0x01 = Sunset, 0x02 = Sunrise, 0x03 = Midnight : un8 = Dimlevel, valid range
 * 0..100 (0=load output off)}
 */
#define VE_REG_DC_OUTPUT_LIGHTING_EVENT0 0xEDA0

/**
 * DC Output Lighting event 1 {sn16 = Time offset [1minutes] : un8 = Event code,
 * 0x01 = Sunset, 0x02 = Sunrise, 0x03 = Midnight : un8 = Dimlevel, valid range
 * 0..100 (0=load output off)}
 */
#define VE_REG_DC_OUTPUT_LIGHTING_EVENT1 0xEDA1

/**
 * DC Output Lighting event 2 {sn16 = Time offset [1minutes] : un8 = Event code,
 * 0x01 = Sunset, 0x02 = Sunrise, 0x03 = Midnight : un8 = Dimlevel, valid range
 * 0..100 (0=load output off)}
 */
#define VE_REG_DC_OUTPUT_LIGHTING_EVENT2 0xEDA2

/**
 * DC Output Lighting event 3 {sn16 = Time offset [1minutes] : un8 = Event code,
 * 0x01 = Sunset, 0x02 = Sunrise, 0x03 = Midnight : un8 = Dimlevel, valid range
 * 0..100 (0=load output off)}
 */
#define VE_REG_DC_OUTPUT_LIGHTING_EVENT3 0xEDA3

/**
 * DC Output Lighting event 4 {sn16 = Time offset [1minutes] : un8 = Event code,
 * 0x01 = Sunset, 0x02 = Sunrise, 0x03 = Midnight : un8 = Dimlevel, valid range
 * 0..100 (0=load output off)}
 */
#define VE_REG_DC_OUTPUT_LIGHTING_EVENT4 0xEDA4

/**
 * DC Output Lighting event 5 {sn16 = Time offset [1minutes] : un8 = Event code,
 * 0x01 = Sunset, 0x02 = Sunrise, 0x03 = Midnight : un8 = Dimlevel, valid range
 * 0..100 (0=load output off)}
 */
#define VE_REG_DC_OUTPUT_LIGHTING_EVENT5 0xEDA5

/**
 * DC Output Lighting dimlevel {un8 = DC Output Lighting dimlevel, Charger load
 * output specific parameters - lighting controller dim setting . dim: valid
 * range 0..100 (0=load output off).@remark this vreg can be used to query the
 * current dimlevel when a timer program is active (e.g. to create an external
 * pwm signal)              }
 */
#define VE_REG_DC_OUTPUT_LIGHTING_DIM 0xEDA6

/** DC Output Midpoint shift {sn16 = DC Output Midpoint shift [1minutes]} */
#define VE_REG_DC_OUTPUT_MIDPOINT_SHIFT 0xEDA7

/** DC Output Status {un8 = DC Output Status, 0 = Off, 1 = On} */
#define VE_REG_DC_OUTPUT_STATUS 0xEDA8

/** DC Output Voltage {un16 = DC Output Voltage [0.01V], 0xFFFF = Not Available} */
#define VE_REG_DC_OUTPUT_VOLTAGE 0xEDA9

/** DC Output Power {un16 = DC Output Power [1W], 0xFFFF = Not Available} */
#define VE_REG_DC_OUTPUT_POWER 0xEDAA

/** DC Output Control Mode {un8 = DC Output Control Mode} */
#define VE_REG_DC_OUTPUT_CONTROL 0xEDAB

/**
 * Charger load output offset voltage {un8 = Charger load output offset voltage
 * [0.01V]}
 */
#define VE_REG_DC_OUTPUT_OFFSET_VOLTAGE 0xEDAC

/** DC Output Current {un16 = DC Output Current [0.1A], 0xFFFF = Not Available} */
#define VE_REG_DC_OUTPUT_CURRENT 0xEDAD

/**
 * DC Output Current Limit {un16 = DC Output Current Limit [0.1A], 0xFFFF = Not
 * Available}
 */
#define VE_REG_DC_OUTPUT_CURRENT_LIMIT 0xEDAE

/**
 * DC Output Current Maximum {un16 = DC Output Current Maximum [0.1A], 0xFFFF =
 * Not Available, Charger load output specific parameters - maximum allowed load
 * current}
 */
#define VE_REG_DC_OUTPUT_MAX_CURRENT 0xEDAF

/**
 * DC Input Disable Protection {un8 = protection, 0 = enabled, 1 = disabled,
 * Charger input specific parameters - disable automatic panel short circuit
 * mechanism}
 */
#define VE_REG_DC_INPUT_DISABLE_PROTECTION 0xEDB7

/**
 * DC Input Max Voltage {un16 = DC Input Max Voltage [0.01V], 0xFFFF = Not
 * Available}
 */
#define VE_REG_DC_INPUT_MAX_VOLTAGE 0xEDB8

/**
 * DC Input Voltage High Clear {un16 = DC Input Voltage High Clear [0.01V],
 * 0xFFFF = Not Available}
 */
#define VE_REG_DC_INPUT_HIGH_VOLTAGE_CLEAR 0xEDB9

/**
 * DC Input Voltage High Set {un16 = DC Input Voltage High Set [0.01V], 0xFFFF =
 * Not Available}
 */
#define VE_REG_DC_INPUT_HIGH_VOLTAGE_SET 0xEDBA

/** DC Input Voltage {un16 = DC Input Voltage [0.01V], 0xFFFF = Not Available} */
#define VE_REG_DC_INPUT_VOLTAGE 0xEDBB

/** DC Input Power {un32 = DC Input Power [0.01W], 0xFFFFFFFF = Not Available} */
#define VE_REG_DC_INPUT_POWER 0xEDBC

/** DC Input Current {un16 = DC Input Current [0.1A], 0xFFFF = Not Available} */
#define VE_REG_DC_INPUT_CURRENT 0xEDBD

/**
 * DC Input Current Limit {un16 = DC Input Current Limit [0.1A], 0xFFFF = Not
 * Available}
 */
#define VE_REG_DC_INPUT_CURRENT_LIMIT 0xEDBE

/**
 * DC Input Current Maximum {un16 = DC Input Current Maximum [0.1A], 0xFFFF = Not
 * Available}
 */
#define VE_REG_DC_INPUT_MAX_CURRENT 0xEDBF

/**
 * Charger specific parameters - charge current during low current mode {un16 =
 * Charger specific parameters - charge current during low current mode [0.1A]}
 */
#define VE_REG_CHR_LOW_CURRENT 0xEDCB

/**
 * Charger Streetlight Version {un8 = Version, Charger specific parameters -
 * streetlight application version}
 */
#define VE_REG_CHR_STREETLIGHT_VERSION 0xEDCC

/** Charger History Version {un8 = Version} */
#define VE_REG_CHR_HISTORY_VERSION 0xEDCD

/**
 * Charger Voltage Settings Range {un8 = Min voltage [1V] : un8 = Max voltage
 * [1V]}
 */
#define VE_REG_CHR_VOLTAGE_SETTINGS_RANGE 0xEDCE

/**
 * Charger Maximum Power Yesterday {un32 = Power [1W], 0xFFFFFFFF = Not
 * Available, Charger specific parameters - charger group maximum power
 * yesterday@remark attention this field has been promoted from un16 to un32,
 * mppt chargers with older firmware may report this as an un16}
 */
#define VE_REG_CHR_YESTERDAY_PMAX 0xEDD0

/**
 * Charger Yield Yesterday {un32 = Charger Yield Yesterday [0.01kWh], 0xFFFFFFFF
 * = Not Available, Some mppt chargers with this as an un16}
 */
#define VE_REG_CHR_YESTERDAY_YIELD 0xEDD1

/** Charger Maximum Power Today {un32 = Power [1W], 0xFFFFFFFF = Not Available} */
#define VE_REG_CHR_TODAY_PMAX 0xEDD2

/**
 * Charger Yield Today {un32 = Charger Yield Today [0.01kWh], 0xFFFFFFFF = Not
 * Available}
 */
#define VE_REG_CHR_TODAY_YIELD 0xEDD3

/**
 * Charger Additional State Information {bits[1] = VE_REG_CUSTOM_STATE_SAFE_MODE,
 * 0 = Off, 1 = On : bits[1] = VE_REG_CUSTOM_STATE_TPTB_MODE, 0 = Off, 1 = On :
 * bits[1] = VE_REG_CUSTOM_STATE_REPEATED_ABS, 0 = Off, 1 = On : bits[1] =
 * reserved 3, 0 = Off, 1 = On : bits[1] = VE_REG_CUSTOM_STATE_TEMP_DIM, 0 = Off,
 * 1 = On : bits[1] = VE_REG_CUSTOM_STATE_SENSE_DIM, 0 = Off, 1 = On : bits[1] =
 * VE_REG_CUSTOM_STATE_INP_CUR_DIM, 0 = Off, 1 = On : bits[1] =
 * VE_REG_CUSTOM_STATE_LOW_POWER_MODE, 0 = Off, 1 = On}
 */
#define VE_REG_CHR_CUSTOM_STATE 0xEDD4

/**
 * Charger Voltage {un16 = Charger Voltage [0.01V], 0xFFFF = Not Available,
 * Charger specific parameters - actual charge voltage                @remark HEX
 * protocol compat. data present in regular NMEA pgn}
 */
#define VE_REG_CHR_VOLTAGE 0xEDD5

/** Charger Power {un16 = Power [1W], 0xFFFF = Not Available} */
#define VE_REG_CHR_POWER 0xEDD6

/**
 * Charger Current {sn16 = Charger Current [0.1A], 0x7FFF = Not Available,
 * Charger specific parameters - actual charge current                @remark HEX
 * protocol compat. data present in regular NMEA pgn}
 */
#define VE_REG_CHR_CURRENT 0xEDD7

/** Charger Relay State {un8 = Relay State, 0x00 = Open, 0x01 = Closed} */
#define VE_REG_CHR_RELAY_CONTROL 0xEDD8

/**
 * Charger Relay Mode {un8 = Relay Mode, WARNING: unsupported values are
 * accepted!}
 */
#define VE_REG_CHR_RELAY_MODE 0xEDD9

/** Charger Error Code {un8 = Error Code} */
#define VE_REG_CHR_ERROR_CODE 0xEDDA

/** Charger Temperature {sn16 = Charger Temperature [0.01°C]} */
#define VE_REG_CHR_TEMPERATURE 0xEDDB

/**
 * Charger User Yield {un32 = Charger User Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available}
 */
#define VE_REG_CHR_USER_YIELD 0xEDDC

/**
 * Charger System Yield {un32 = Charger System Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available}
 */
#define VE_REG_CHR_SYSTEM_YIELD 0xEDDD

/** Charger number of physical outputs {un8 = Outputs} */
#define VE_REG_CHR_OUTPUTS 0xEDDE

/**
 * Charger Maximum Current {un16 = Charger Maximum Current [0.1A], 0xFFFF = Not
 * Available}
 */
#define VE_REG_CHR_MAX_CURRENT 0xEDDF

/**
 * low-temp charge current {un16 = low-temp charge current [0.1A], 0 = stop
 * charging, 0xFFFF = use maximum charger current}
 */
#define VE_REG_BAT_LOW_TEMP_CHARGE_CURRENT 0xEDE6

/**
 * Battery Tail Current {un16 = Battery Tail Current [0.1A], 0xFFFF = Not
 * Available}
 */
#define VE_REG_BAT_TAIL_CURRENT 0xEDE7

/** BMS Present {un8 = BMS Present, 0 = No, 1 = Yes} */
#define VE_REG_BAT_BMS_PRESENT 0xEDE8

/**
 * Power Supply Mode Voltage {un16 = Power Supply Mode Voltage [0.01V], 0xFFFF =
 * Not Available, Charger battery parameters - power supply mode voltage setting
 * .read: the parameter as it is currently in use (set VE_REG_BAT_TYPE to 0xFF to
 * use and read the user-defined setting).write: always writes to the user-
 * defined setting in non-volatile memory important for mppt chargers@remark
 * important for mppt chargers: always set the @ref VE_REG_BAT_VOLTAGE register
 * to the correct system voltage before writing to this register}
 */
#define VE_REG_BAT_PSU_V 0xEDE9

/** Battery Voltage Setting {un8 = Battery Voltage Setting [1V]} */
#define VE_REG_BAT_VOLTAGE_SETTING 0xEDEA

/**
 * Battery Overcharge Voltage Level (upper alarm boundary) {un16 = Battery
 * Overcharge Voltage Level (upper alarm boundary) [0.01V], 0xFFFF = Not
 * Available, high voltage alarm do not implement this vreg in tooling, use
 * VE_REG_RELAY_HIGH_VOLTAGE_SET and VE_REG_RELAY_HIGH_VOLTAGE_CLEAR instead used
 * in all Skylla-i chargers and ve.can mppt <v2.00 important for mppt chargers:
 * always set the VE_REG_BAT_VOLTAGE register to the correct system voltage
 * before writing to this register}
 */
#define VE_REG_BAT_HIGH_V 0xEDEB

/** Battery Temperature {un16 = Battery Temperature [0.01K], 0xFFFF = Unavailable} */
#define VE_REG_BAT_TEMPERATURE 0xEDEC

/**
 * Battery Intelligent Mode {un8 = Intelligent Mode, 0 = Off, 1 = On, (detect
 * state of charge at startup) read: the parameter as it is currently in use (set
 * VE_REG_BAT_TYPE to 0xFF to use and read the user-defined setting).
 * @remark write: always writes to the user-defined setting in non-volatile
 * memory.                }
 */
#define VE_REG_BAT_INTELLIGENT_MODE 0xEDED

/**
 * Battery Storage Mode {un8 = Storage Mode, 0 = Off, 1 = On, read: the parameter
 * as it is currently in use (set VE_REG_BAT_TYPE to 0xFF to use and read the
 * user-defined setting).                @remark write: always writes to the
 * user-defined setting in non-volatile memory}
 */
#define VE_REG_BAT_STORAGE_MODE 0xEDEE

/**
 * Battery Voltage Selection {un8 = Battery Voltage Selection [1V], this vreg
 * reports the actual voltage used (relevant for devices                with
 * automatic voltage detection), use VE_REG_BAT_VOLTAGE_SETTING to get the
 * user setting ve.direct mppt <v1.08: read = get user battery voltage setting,
 * write = set user battery voltage setting ve.direct mppt >v1.09: read = get
 * detected battery voltage, write = set user battery voltage setting ve.can
 * mppt <v2.00: read = get user battery voltage setting, write = set user
 * battery voltage setting ve.can mppt >v2.01: read = get detected battery
 * voltage, write = set user battery voltage setting note: for models that do not
 * report the detected voltage: the detected voltage can be derived from the
 * battery                parameters (e.g. VE_REG_BAT_ABSORPTION_V)}
 */
#define VE_REG_BAT_VOLTAGE 0xEDEF

/**
 * Battery Maximum Current {un16 = Battery Maximum Current [0.1A], 0xFFFF = Not
 * Available, read: the parameter as it is currently in use (set VE_REG_BAT_TYPE
 * to 0xFF to use and read the user-defined setting).                @remark
 * write: always writes to the user-defined setting in non-volatile memory.}
 */
#define VE_REG_BAT_MAX_CURRENT 0xEDF0

/**
 * Battery Type {un8 = Battery Type, 0x00 = charger disabled, 0xFF = User
 * Defined}
 */
#define VE_REG_BAT_TYPE 0xEDF1

/**
 * Battery Temperature Compensation Level {sn16 = Temperature Compensation
 * [0.01mV/°C], read: the parameter as it is currently in use (set
 * VE_REG_BAT_TYPE to 0xFF to use and read the user-defined setting) write:
 * always writes to the user-defined setting in non-volatile memory.@remark
 * important for mppt chargers: always set the @ref VE_REG_BAT_VOLTAGE register
 * to the correct system voltage before writing to this register}
 */
#define VE_REG_BAT_TEMP_COMP 0xEDF2

/**
 * Battery Discharge Voltage Level (lower alarm boundary) {un16 = Battery
 * Discharge Voltage Level (lower alarm boundary) [0.01V], 0xFFFF = Not
 * Available, low voltage alarm do not implement this vreg in tooling, use @ref
 * VE_REG_RELAY_LOW_VOLTAGE_SET and @REF VE_REG_RELAY_LOW_VOLTAGE_CLEAR instead
 * used in all Skylla-i chargers and ve.can mppt chargers up to and including
 * 2.00 important for mppt chargers: always set the VE_REG_BAT_VOLTAGE register
 * to the correct system voltage before writing to this register}
 */
#define VE_REG_BAT_DISCHARGE_V 0xEDF3

/**
 * Battery Equalisation Voltage Level {un16 = Battery Equalisation Voltage Level
 * [0.01V], 0xFFFF = Not Available}
 */
#define VE_REG_BAT_EQUAL_V 0xEDF4

/**
 * Battery Storage Voltage Level {un16 = Battery Storage Voltage Level [0.01V],
 * 0xFFFF = Not Available}
 */
#define VE_REG_BAT_STORAGE_V 0xEDF5

/**
 * Battery Float Voltage Level {un16 = Battery Float Voltage Level [0.01V],
 * 0xFFFF = Not Available}
 */
#define VE_REG_BAT_FLOAT_V 0xEDF6

/**
 * Battery Absorption Voltage Level {un16 = Battery Absorption Voltage Level
 * [0.01V], 0xFFFF = Not Available}
 */
#define VE_REG_BAT_ABSORPTION_V 0xEDF7

/**
 * Battery Repeated Absorption Time Interval {un16 = Battery Repeated Absorption
 * Time Interval [0.01days]}
 */
#define VE_REG_BAT_REPABS_T_INT 0xEDF8

/**
 * Battery Repeated Absorption Time Duration {un16 = Battery Repeated Absorption
 * Time Duration [0.01hours]}
 */
#define VE_REG_BAT_REPABS_T_DUR 0xEDF9

/**
 * Battery Float Time Limit {un16 = Battery Float Time Limit [0.01hours], 0x0000
 * = Off}
 */
#define VE_REG_BAT_FLOAT_T_LIMIT 0xEDFA

/**
 * Battery Absorption Time Limit {un16 = Battery Absorption Time Limit
 * [0.01hours], 0x0000 = Off}
 */
#define VE_REG_BAT_ABS_T_LIMIT 0xEDFB

/**
 * Battery Bulk Time Limit {un16 = Battery Bulk Time Limit [0.01hours], 0x0000 =
 * Off}
 */
#define VE_REG_BAT_BULK_T_LIMIT 0xEDFC

/**
 * Battery Automatic Equalisation Mode {un8 = Battery Automatic Equalisation
 * Mode, 0x0000 = Off, 1..250=repeat every n days (1=every day, 2=every other
 * day, etc)}
 */
#define VE_REG_BAT_TRACTION_CURVE 0xEDFD

/** Battery Adaptive Mode {un8 = Battery Adaptive Mode, 0 = Off, 1 = On} */
#define VE_REG_BAT_ADAPTIVE_MODE 0xEDFE

/** Battery Safe Mode {un8 = Battery Safe Mode, 0 = Off, 1 = On} */
#define VE_REG_BAT_SAFE_MODE 0xEDFF

/** Only used to support the BMV, use @ref VE_REG_HIST_DEEPEST_DISCHARGE instead. */
#define VE_REG_BMV_H1 0xEE00

/** Only used to support the BMV, use @ref VE_REG_HIST_LAST_DISCHARGE instead. */
#define VE_REG_BMV_H2 0xEE01

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_NR_OF_CHARGE_CYCLES
 * instead.
 */
#define VE_REG_BMV_H3 0xEE02

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_NR_OF_FULL_DISCHARGES
 * instead.
 */
#define VE_REG_BMV_H4 0xEE03

/** Only used to support the BMV, use @ref VE_REG_HIST_CUMULATIVE_AH instead. */
#define VE_REG_BMV_H5 0xEE04

/** Only used to support the BMV, use @ref VE_REG_HIST_MIN_VOLTAGE instead. */
#define VE_REG_BMV_H6 0xEE05

/** Only used to support the BMV, use @ref VE_REG_HIST_MAX_VOLTAGE instead. */
#define VE_REG_BMV_H7 0xEE06

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_SECS_SINCE_LAST_FULL_CHARGE
 * instead.
 */
#define VE_REG_BMV_H8 0xEE07

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_SECS_SINCE_LAST_FULL_CHARGE
 * instead.
 */
#define VE_REG_BMV_H9 0xEE08

/** Only used to support the BMV, use @ref VE_REG_HIST_NR_OF_AUTO_SYNCS instead. */
#define VE_REG_BMV_H10 0xEE09

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_NR_OF_LOW_VOLTAGE_ALARMS
 * instead.
 */
#define VE_REG_BMV_H11 0xEE0A

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_NR_OF_HIGH_VOLTAGE_ALARMS
 * instead.
 */
#define VE_REG_BMV_H12 0xEE0B

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_NR_OF_LOW_VOLTAGE_2_ALARMS
 * instead.
 */
#define VE_REG_BMV_H13 0xEE0C

/**
 * Only used to support the BMV, use @ref VE_REG_HIST_NR_OF_HIGH_VOLTAGE_2_ALARMS
 * instead.
 */
#define VE_REG_BMV_H14 0xEE0D

/** Only used to support the BMV, use @ref VE_REG_HIST_MIN_VOLTAGE_2 instead. */
#define VE_REG_BMV_H15 0xEE0E

/** Only used to support the BMV, use @ref VE_REG_HIST_MAX_VOLTAGE_2 instead. */
#define VE_REG_BMV_H16 0xEE0F

/** Output setpoint {un16 = Output setpoint [0.01V]} */
#define VE_REG_BPC_TST_OUTPUT_SETPOINT 0xEE40

/** Tester product id {un16 = Tester product id} */
#define VE_REG_TST_PRODUCT_ID 0xEE7C

/** Tester Command {un16 = Tester Command} */
#define VE_REG_TST_TST_EXEC_CMD 0xEE7D

/** UDF Data {un8 = reserved} */
#define VE_REG_UDF_DATA 0x012E

/**
 * History Total {un8 = Version, 0 = , 1 =  : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un32 = Total yield user [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Total yield system [0.01kWh], 0xFFFFFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un8 = Number of
 * available days : , 1 = }
 */
#define VE_REG_HISTORY_TOTAL 0x104F

/**
 * History Day 0 (today) {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY00 0x1050

/**
 * History Day -1 (yesterday) {un8 = Reserved : un32 = Yield [0.01kWh],
 * 0xFFFFFFFF = Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not
 * Available : un16 = Battery voltage max [0.01V], 0xFFFF = Not Available : un16
 * = Battery voltage min [0.01V], 0xFFFF = Not Available : un8 = Error database
 * id, 0 = ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error
 * 1 : un8 = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY01 0x1051

/**
 * History Day -2 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY02 0x1052

/**
 * History Day -2 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY03 0x1053

/**
 * History Day -4 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY04 0x1054

/**
 * History Day -5 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY05 0x1055

/**
 * History Day -6 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY06 0x1056

/**
 * History Day -7 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY07 0x1057

/**
 * History Day -8 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY08 0x1058

/**
 * History Day -9 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY09 0x1059

/**
 * History Day -10 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY10 0x105A

/**
 * History Day -11 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY11 0x105B

/**
 * History Day -12 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY12 0x105C

/**
 * History Day -13 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY13 0x105D

/**
 * History Day -14 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY14 0x105E

/**
 * History Day -15 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY15 0x105F

/**
 * History Day -16 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY16 0x1060

/**
 * History Day -17 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY17 0x1061

/**
 * History Day -18 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY18 0x1062

/**
 * History Day -19 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY19 0x1063

/**
 * History Day -20 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY20 0x1064

/**
 * History Day -21 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY21 0x1065

/**
 * History Day -22 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY22 0x1066

/**
 * History Day -22 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY23 0x1067

/**
 * History Day -24 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY24 0x1068

/**
 * History Day -25 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY25 0x1069

/**
 * History Day -26 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY26 0x106A

/**
 * History Day -27 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY27 0x106B

/**
 * History Day -28 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY28 0x106C

/**
 * History Day -29 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY29 0x106D

/**
 * History Day -30 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_HISTORY_DAY30 0x106E

/**
 * Link History Total {un8 = Reserved : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un32 = Total yield user [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Total yield system [0.01kWh], 0xFFFFFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un8 = Number of
 * available days : un16 = Battery voltage min [0.01V], 0xFFFF = Not Available}
 */
#define VE_REG_LINK_HISTORY_TOTAL 0x204F

/**
 * Link History Day 0 (today) {un8 = Reserved : un32 = Yield [0.01kWh],
 * 0xFFFFFFFF = Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not
 * Available : un16 = Battery voltage max [0.01V], 0xFFFF = Not Available : un16
 * = Battery voltage min [0.01V], 0xFFFF = Not Available : un8 = Error database
 * id, 0 = ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error
 * 1 : un8 = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY00 0x2050

/**
 * Link History Day -1 (yesterday) {un8 = Reserved : un32 = Yield [0.01kWh],
 * 0xFFFFFFFF = Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not
 * Available : un16 = Battery voltage max [0.01V], 0xFFFF = Not Available : un16
 * = Battery voltage min [0.01V], 0xFFFF = Not Available : un8 = Error database
 * id, 0 = ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error
 * 1 : un8 = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY01 0x2051

/**
 * Link History Day -2 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY02 0x2052

/**
 * Link History Day -2 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY03 0x2053

/**
 * Link History Day -4 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY04 0x2054

/**
 * Link History Day -5 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY05 0x2055

/**
 * Link History Day -6 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY06 0x2056

/**
 * Link History Day -7 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY07 0x2057

/**
 * Link History Day -8 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY08 0x2058

/**
 * Link History Day -9 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF = Not
 * Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY09 0x2059

/**
 * Link History Day -10 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY10 0x205A

/**
 * Link History Day -11 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY11 0x205B

/**
 * Link History Day -12 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY12 0x205C

/**
 * Link History Day -12 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY13 0x205D

/**
 * Link History Day -14 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY14 0x205E

/**
 * Link History Day -15 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY15 0x205F

/**
 * Link History Day -16 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY16 0x2060

/**
 * Link History Day -17 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY17 0x2061

/**
 * Link History Day -18 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY18 0x2062

/**
 * Link History Day -19 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY19 0x2063

/**
 * Link History Day -20 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY20 0x2064

/**
 * Link History Day -21 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY21 0x2065

/**
 * Link History Day -22 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY22 0x2066

/**
 * Link History Day -22 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY23 0x2067

/**
 * Link History Day -24 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY24 0x2068

/**
 * Link History Day -25 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY25 0x2069

/**
 * Link History Day -26 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY26 0x206A

/**
 * Link History Day -27 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY27 0x206B

/**
 * Link History Day -28 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY28 0x206C

/**
 * Link History Day -29 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY29 0x206D

/**
 * Link History Day -30 {un8 = Reserved : un32 = Yield [0.01kWh], 0xFFFFFFFF =
 * Not Available : un32 = Consumed [0.01kWh], 0xFFFFFFFF = Not Available : un16 =
 * Battery voltage max [0.01V], 0xFFFF = Not Available : un16 = Battery voltage
 * min [0.01V], 0xFFFF = Not Available : un8 = Error database id, 0 =
 * ERROR_DB_CHARGERS, 0xFF = Not available : un8 = Error 0 : un8 = Error 1 : un8
 * = Error 2 : un8 = Error 3 : un16 = Time Bulk [1minutes], 0xFFFF = Not
 * Available : un16 = Time Absorption [1minutes], 0xFFFF = Not Available : un16 =
 * Time Float [1minutes], 0xFFFF = Not Available : un32 = Max power [1W],
 * 0xFFFFFFFF = Not Available : un16 = Battery current max [0.1A], 0xFFFF = Not
 * Available : un16 = Panel voc max [0.01V], 0xFFFF = Not Available : un16 = Day
 * sequence number}
 */
#define VE_REG_LINK_HISTORY_DAY30 0x206E

/** BMS page BMV flags {un32 = BMS page BMV flags} */
#define VE_REG_BMS_FLAGS 0x2100

/** SmartLithium error flags {un32 = SmartLithium error flags} */
#define VE_REG_SMART_LITHIUM_ERROR_FLAGS 0xEC80

/**
 * Pin code for BLE devices Codes are decimal characters. {stringFixed[6] = old
 * code : stringFixed[6] = new code}
 */
#define VE_REG_PINCODE 0xEC10

/** PUK code for BLE devices {stringZeroEnded[32] = puk code} */
#define VE_REG_PUKCODE 0xEC11

/** Tester measured value (datatype depends on device implementation) */
#define VE_REG_TST_MEAS_GET 0xEE80

/**
 * Tester ADC calibration offset (datatype depends on device implementation)
 * {Float = Tester ADC calibration offset (datatype depends on device
 * implementation)}
 */
#define VE_REG_TST_ADC_CAL_OFFSET 0xEEA0

/** Tester ADC calibration gain (datatype depends on device implementation) */
#define VE_REG_TST_ADC_CAL_GAIN 0xEEC0

/** Equal to VE_REG_BMV_CE */
#define VE_REG_CAH 0xEEFF

/** Device instance {un8 = Instance} */
#define VE_REG_DEVICE_INSTANCE 0x0105

/** Device class {un8 = Class : un8 = Function} */
#define VE_REG_DEVICE_CLASS 0x0106

/** Serial number {stringZeroEnded[32] = Serial : un8 = padding, 0 = zeropadding} */
#define VE_REG_SERIAL_NUMBER 0x010A

/** Model name {stringZeroEnded[64] = Model : un8 = padding, 0 = zeropadding} */
#define VE_REG_MODEL_NAME 0x010B

/** Description 1 {stringZeroEnded[64] = Serial} */
#define VE_REG_DESCRIPTION1 0x010C

/** Description 2 {stringZeroEnded[64] = Serial} */
#define VE_REG_DESCRIPTION2 0x010D

/**
 * Signals that there is an update available {un16 = Flags, bit 0 isAvailable
 * Whether an update is available bit 1 isMandatory Whether the update is
 * mandatory before the product can be used bit 2 . . 15 Reserved : un32 =
 * FromVersion The app version the product now has : un32 = ToVersion, The app
 * version of the new firmware}
 */
#define VE_REG_UPDATE_AVAILABLE 0x0018

/** Update progress {un8 = progress percentage [1%]} */
#define VE_REG_UPDATE_PROGRESS 0x0019

/** Start available update */
#define VE_REG_UPDATE_START_AVAILABLE 0x001A

/** Connect {un8 = child device : un8 = request, 0 = Disconnect, 1 = Connect} */
#define VE_REG_CONNECT 0x0060

#define VE_REG_LAST_MESSAGE 0xEC00

#define VE_REG_HSDS 0xEC01

#define VE_REG_VER 0xEC02

#define VE_REG_PROD 0xEC03

#define VE_REG_BMV 0xEC04

/**
 * @remark The next block is only used for the tester LCD memory {stringFixed[14]
 * = @remark The next block is only used for the tester LCD memory}
 */
#define VE_REG_BMV_TST_LCD_MEM 0xEE90

/**
 * Button state 0x0004=BUTTON_SETUP, 0x0008=BUTTON_SELECT, 0x0010=BUTTON_MINUS,
 * 0x0020=BUTTON_PLUS. {un16 = Button state 0x0004=BUTTON_SETUP,
 * 0x0008=BUTTON_SELECT, 0x0010=BUTTON_MINUS, 0x0020=BUTTON_PLUS.}
 */
#define VE_REG_BMV_TST_BTN_STATE 0xEE91

/** Store calibration to flash. */
#define VE_REG_BMV_TST_STORE_CAL 0xEE92

/** Test relay {un8 = Test relay, 0 = close, 1 = open} */
#define VE_REG_BMV_TST_RELAY 0xEE93

/** Test backlight : 0-9. {un8 = Test backlight : 0-9.} */
#define VE_REG_BMV_TST_BACKLIGHT 0xEE94

/**  {un8 = , 0 = off, 1 = on} */
#define VE_REG_BMV_TST_BUZZER 0xEE95

/** Test clock : counts. {un16 = Test clock : counts.} */
#define VE_REG_BMV_TST_CLOCK 0xEE96

/**
 * @remark The next block is only used for the tester ADC voltage counts {Float =
 * @remark The next block is only used for the tester ADC voltage counts}
 */
#define VE_REG_BMV_ADC_VOLTAGE_COUNTS 0xEEA0

/** ADC auxiliary voltage counts {Float = ADC auxiliary voltage counts} */
#define VE_REG_BMV_ADC_AUX_VOLTAGE_COUNTS 0xEEA1

/** ADC current counts {Float = ADC current counts} */
#define VE_REG_BMV_ADC_CURRENT_COUNTS 0xEEA2

/**
 * @remark The next block is only used for the tester Voltage {Float = @remark
 * The next block is only used for the tester Voltage [V]}
 */
#define VE_REG_BMV_VOLTAGE 0xEEB0

/** Auxiliary voltage {Float = Auxiliary voltage [V]} */
#define VE_REG_BMV_AUX_VOLTAGE 0xEEB1

/** Current {Float = Current [A]} */
#define VE_REG_BMV_CURRENT 0xEEB2

/** Consumed AH {Float = Consumed AH [Ah]} */
#define VE_REG_BMV_CAH 0xEEB3

/** SOC {Float = SOC [%]} */
#define VE_REG_BMV_SOC 0xEEB4

/** TTG {Float = TTG} */
#define VE_REG_BMV_TTG 0xEEB5

/** Synchronized {un8 = Synchronized, 0 = not synced, 1 = synced} */
#define VE_REG_BMV_SYNCHRONIZED 0xEEB6

/** Temperature in Fahrenheit. {Float = Temperature in Fahrenheit.} */
#define VE_REG_BMV_TEMPERATURE 0xEEB7

/**
 * @remark The next block is only used for the tester Voltage offset {Float =
 * @remark The next block is only used for the tester Voltage offset}
 */
#define VE_REG_BMV_CAL2_VOLTAGE_OFFSET 0xEEC0

/** Voltage gain {Float = Voltage gain} */
#define VE_REG_BMV_CAL2_VOLTAGE_GAIN 0xEEC1

/** Voltage2 offset {Float = Voltage2 offset} */
#define VE_REG_BMV_CAL2_VOLTAGE_2_OFFSET 0xEEC2

/** Voltage2 gain {Float = Voltage2 gain} */
#define VE_REG_BMV_CAL2_VOLTAGE_2_GAIN 0xEEC3

/** Current offset {Float = Current offset} */
#define VE_REG_BMV_CAL2_CURRENT_OFFSET 0xEEC4

/** Current gain {Float = Current gain} */
#define VE_REG_BMV_CAL2_CURRENT_GAIN 0xEEC5

/**
 * Calibrated fields : calibrated if LSB is 0. {un16 = Calibrated fields :
 * calibrated if LSB is 0.}
 */
#define VE_REG_BMV_CAL2_CALIBRATED 0xEEC6

/** Serial number {stringFixed[32] = Serial number} */
#define VE_REG_BMV_CAL2_SERIAL 0xEEC7

/**
 * @remark The next block is only used for the tester Voltage offset {Float =
 * @remark The next block is only used for the tester Voltage offset}
 */
#define VE_REG_BMV_CAL_VOLTAGE_OFFSET 0xEED0

/** Voltage gain {Float = Voltage gain} */
#define VE_REG_BMV_CAL_VOLTAGE_GAIN 0xEED1

/** Voltage2 offset {Float = Voltage2 offset} */
#define VE_REG_BMV_CAL_VOLTAGE_2_OFFSET 0xEED2

/** Voltage2 gain {Float = Voltage2 gain} */
#define VE_REG_BMV_CAL_VOLTAGE_2_GAIN 0xEED3

/** Current offset {Float = Current offset} */
#define VE_REG_BMV_CAL_CURRENT_OFFSET 0xEED4

/** Current gain {Float = Current gain} */
#define VE_REG_BMV_CAL_CURRENT_GAIN 0xEED5

/**
 * Calibrated fields : calibrated if LSB is 0. {un16 = Calibrated fields :
 * calibrated if LSB is 0.}
 */
#define VE_REG_BMV_CAL_CALIBRATED 0xEED6

/**
 * Show voltage in status menu {un8 = Show voltage in status menu, 0 = no, 1 =
 * yes}
 */
#define VE_REG_BMV_SHOW_VOLTAGE 0xEEE0

/**
 * Show auxiliairy voltage in status menu {un8 = Show auxiliairy voltage in
 * status menu, 0 = no, 1 = yes}
 */
#define VE_REG_BMV_SHOW_AUX_VOLTAGE 0xEEE1

/**
 * Show mid voltage in status menu {un8 = Show mid voltage in status menu, 0 =
 * no, 1 = yes}
 */
#define VE_REG_BMV_SHOW_MID_VOLTAGE 0xEEE2

/**
 * Show current in status menu {un8 = Show current in status menu, 0 = no, 1 =
 * yes}
 */
#define VE_REG_BMV_SHOW_CURRENT 0xEEE3

/** Show AH in status menu {un8 = Show AH in status menu, 0 = no, 1 = yes} */
#define VE_REG_BMV_SHOW_AH 0xEEE4

/** Show SOC in status menu. {un8 = Show SOC in status menu., 0 = no, 1 = yes} */
#define VE_REG_BMV_SHOW_SOC 0xEEE5

/** Show TTG in status menu {un8 = Show TTG in status menu, 0 = no, 1 = yes} */
#define VE_REG_BMV_SHOW_TTG 0xEEE6

/**
 * Show temperature in status menu {un8 = Show temperature in status menu, 0 =
 * no, 1 = yes}
 */
#define VE_REG_BMV_SHOW_TEMPERATURE 0xEEE7

/** Show power in status menu {un8 = Show power in status menu, 0 = no, 1 = yes} */
#define VE_REG_BMV_SHOW_POWER 0xEEE8

/** Temperature coefficient {un16 = Temperature coefficient} */
#define VE_REG_BMV_TEMPERATURE_COEFFICIENT 0xEEF4

/** Scroll speed {un8 = Scroll speed} */
#define VE_REG_BMV_SCROLL_SPEED 0xEEF5

/** Lock setup {un8 = Lock setup, 0 = unlocked, 1 = locked} */
#define VE_REG_BMV_SETUP_LOCK 0xEEF6

/** Temperature unit {un8 = Temperature unit, 0 = Celcius, 1 = Fahrenheit} */
#define VE_REG_BMV_TEMPERATURE_UNIT 0xEEF7

/**
 * Auxiliairy input mode {un8 = Auxiliairy input mode, 0 = aux, 1 = mid, 2 =
 * temperature}
 */
#define VE_REG_BMV_AUX_INPUT 0xEEF8

/** Software version {un16 = Software version} */
#define VE_REG_BMV_SW_VERSION 0xEEF9

/** Shunt max voltage {un16 = Shunt max voltage [0.001V]} */
#define VE_REG_BMV_SHUNT_VOLTS 0xEEFA

/** Shunt max current {un16 = Shunt max current [1A]} */
#define VE_REG_BMV_SHUNT_AMPS 0xEEFB

/**
 * Sound buzzer when alarm active {un8 = Sound buzzer when alarm active, 0 = off,
 * 1 = on}
 */
#define VE_REG_BMV_ALARM_BUZZER_ON 0xEEFC

/** Backlight intensity : 0-9 {un8 = Backlight intensity : 0-9} */
#define VE_REG_BMV_BACKLIGHT 0xEEFE

/** Consumed Ah {sn32 = Consumed Ah [0.1Ah]} */
#define VE_REG_BMV_CE 0xEEFF

/** Tester raw ADC value {un16 = raw adc value} */
#define VE_REG_TST_ADC_GET_RAW 0xEEE0

/**  {un16 = , tester} */
#define VE_REG_VOLTAGE_RANGE_MIN 0x2211

/**  {un16 = , tester} */
#define VE_REG_VOLTAGE_RANGE_MAX 0x2212

/** typeOperatingMode tester */
#define VE_REG_INV_OPER_OPERATING_MODE 0xEB00

/** typeOperState readonly */
#define VE_REG_INV_OPER_GET_STATE 0xEB01

/**  {un16 = data} */
#define VE_REG_INV_MOD_GET_WAVE_AMPLITUDE 0xEB02

/** veBool */
#define VE_REG_INV_WAVE_SET50HZ_NOT60HZ 0xEB03

/**  {un16 = data} */
#define VE_REG_INV_OPER_ECO_MODE_IINV_MIN 0xEB04

/**  {un8 = data} */
#define VE_REG_INV_OPER_ECO_MODE_IS_IINV_COUNT 0xEB05

/**  {un8 = data [0.25s]} */
#define VE_REG_INV_OPER_ECO_MODE_RETRY_TIME 0xEB06

/**  {un16 = data, tester} */
#define VE_REG_INV_MOD_FAST_IPEAK 0xEB07

/** typeProtState readonly */
#define VE_REG_INV_PROT_GET_STATE 0xEB08

/**  {un16 = data, tester} */
#define VE_REG_INV_MOD_FAST_UPEAK 0xEB09

/**  {un16 = data} */
#define VE_REG_INV_ADC_UINV_RAW 0xEB20

/**  {un16 = data} */
#define VE_REG_INV_ADC_UBAT_RAW 0xEB22

/**  {un16 = data} */
#define VE_REG_INV_ADC_UTRANSF_RAW 0xEB23

/**  {un16 = data} */
#define VE_REG_INV_ADC_UTEMP_FET_RAW 0xEB24

/**  {un16 = data} */
#define VE_REG_INV_ADC_UTEMP_MICRO_RAW 0xEB25

/**  {un16 = data} */
#define VE_REG_INV_ADC_UPOTMETER_RAW 0xEB26

/**  {un16 = data} */
#define VE_REG_INV_ADC_XRAW 0xEB27

/**  {un16 = data} */
#define VE_REG_INV_ADC_UINV 0xEB28

/**  {un16 = data} */
#define VE_REG_INV_ADC_UBAT 0xEB2A

/**  {un16 = data} */
#define VE_REG_INV_ADC_UTEMP_TRANSF 0xEB2B

/**  {un16 = data} */
#define VE_REG_INV_ADC_UTEMP_FET 0xEB2C

/**  {un16 = data} */
#define VE_REG_INV_ADC_UTEMP_MICRO 0xEB2D

/**  {un16 = data} */
#define VE_REG_INV_ADC_UPOTMETER 0xEB2E

/**  {un16 = data} */
#define VE_REG_INV_ADC_UINV_MEAN 0xEB30

/**  {un16 = data} */
#define VE_REG_INV_ADC_UBAT_MEAN 0xEB32

/**  {un16 = data} */
#define VE_REG_INV_ADC_UREF_ADC 0xEB39

/** un32 readonly */
#define VE_REG_INV_ADC_UINV_MEAN_SQUARE 0xEB3A

/** un32 readonly */
#define VE_REG_INV_ADC_UBAT_MEAN_SQUARE 0xEB3C

/**  {sn16 = data} */
#define VE_REG_INV_ADC_TEMP_TRANSF_D_C 0xEB3D

/**  {sn16 = data} */
#define VE_REG_INV_ADC_TEMP_FET_D_C 0xEB3E

/**  {sn16 = data} */
#define VE_REG_INV_ADC_TEMP_MICRO_D_C 0xEB3F

/** typeLoop tester */
#define VE_REG_INV_LOOP_OPTIONS 0xEB40

/** tester {un16 = data} */
#define VE_REG_INV_LOOP_NULL_AMPLITUDE 0xEB41

/** tester {un16 = data} */
#define VE_REG_INV_LOOP_ERROR_GAIN 0xEB43

/** tester {un16 = data} */
#define VE_REG_INV_LOOP_UINV_REFERENCE 0xEB45

/**  {sn32 = data} */
#define VE_REG_INV_LOOP_GET_UOUT 0xEB46

/**  {un8 = data} */
#define VE_REG_INV_PROT_GET_IPEAK_LOWLEVEL_EVENT 0xEB48

/**  {un8 = data} */
#define VE_REG_INV_PROT_GET_IPEAK_HIGHLEVEL_EVENT 0xEB49

/**  {un8 = data} */
#define VE_REG_INV_PROT_GET_UPEAK_EVENT 0xEB4A

/** tester {un16 = data} */
#define VE_REG_INV_LOOP_UBAT_REFERENCE 0xEB4B

/**  {sn16 = data} */
#define VE_REG_INV_LOOP_GET_ERROR 0xEB4C

/**  {un16 = data} */
#define VE_REG_INV_LOOP_GET_ERROR_INTEGRATED 0xEB4D

/**  {sn16 = data} */
#define VE_REG_INV_LOOP_GET_IINV 0xEB4E

/** tester {un16 = data} */
#define VE_REG_INV_LOOP_COMPENSATE_ROUT_GIN 0xEB4F

/** tester {un16 = data} */
#define VE_REG_INV_LOOP_AMPLITUDE_CLAMP 0xEB50

/** tester {un16 = data} */
#define VE_REG_INV_LOOP_COMPUTE_IINV_GIN 0xEB51

/** typeProtections tester */
#define VE_REG_INV_PROT_ENABLE_MASK 0xEB52

/**  {sn8 = data} */
#define VE_REG_INV_PROT_GET_ACTIVE_LEVEL 0xEB53

/**  {sn8 = data} */
#define VE_REG_INV_PROT_GET_HICKUP_COUNT 0xEB54

/** typeProtWhat readonly */
#define VE_REG_INV_PROT_GET_ACTIVE_ALARM 0xEB55

/** sn8 readonly */
#define VE_REG_INV_PROT_GET_UINV_STATUS 0xEB56

/** sn8 readonly */
#define VE_REG_INV_PROT_GET_IINV_STATUS 0xEB57

/** sn8 readonly */
#define VE_REG_INV_PROT_GET_UBAT_STATUS 0xEB58

/** sn8 readonly */
#define VE_REG_INV_PROT_GET_TEMP_STATUS 0xEB59

/** sn8 readonly */
#define VE_REG_INV_PROT_GET_IPEAK_COUNT_STATUS 0xEB5A

/** sn8 readonly */
#define VE_REG_INV_PROT_GET_UBAT_RIPPLE_STATUS 0xEB5B

/** typeProtections tester */
#define VE_REG_INV_PROT_ENABLE_HICKUP 0xEB5C

/** typeProtections */
#define VE_REG_INV_PROT_ENABLE_WAIT4EVER 0xEB5D

/** tester {un8 = data} */
#define VE_REG_INV_PROT_HICKUP_ATTEMPT_COUNT 0xEB5E

/** tester {un16 = data} */
#define VE_REG_INV_PROT_HICKUP_RESTART_DELAY 0xEB5F

/** tester {un16 = data} */
#define VE_REG_INV_PROT_HICKUP_TIME_OUT 0xEB60

/** typeGpioAlarmLed readonly */
#define VE_REG_INV_GPIO_ALARM_LED_STATE 0xEB61

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UINV_LEVEL_LOW 0xEB62

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UINV_IS_LOW_COUNT 0xEB63

/** tester {un16 = data} */
#define VE_REG_INV_PROT_IINV_LEVEL_WARNING_HIGH 0xEB64

/** tester {un16 = data} */
#define VE_REG_INV_PROT_IINV_IS_WARNING_HIGH_COUNT 0xEB65

/** tester {un16 = data} */
#define VE_REG_INV_PROT_IINV_LEVEL_HIGH 0xEB66

/** tester {un16 = data} */
#define VE_REG_INV_PROT_IINV_IS_HIGH_TIMEOUT 0xEB67

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_LEVEL_HIGH 0xEB68

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_IS_HIGH_COUNT 0xEB69

/** un16 */
#define VE_REG_INV_PROT_UBAT_LEVEL_WARNING_LOW 0xEB6A

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_IS_WARNING_LOW_COUNT 0xEB6B

/** un16 */
#define VE_REG_INV_PROT_UBAT_LEVEL_LOW 0xEB6C

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_IS_LOW_COUNT 0xEB6D

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_LEVEL2LOW 0xEB6E

/** tester {un8 = data} */
#define VE_REG_INV_PROT_TEMP_FET_WARNING_HIGH_C 0xEB6F

/** tester {un8 = data} */
#define VE_REG_INV_PROT_TEMP_FET2HIGH_C 0xEB70

/** tester {un8 = data} */
#define VE_REG_INV_PROT_IPEAK_LOW_LEVEL_INCREMENT 0xEB72

/** tester {un8 = data} */
#define VE_REG_INV_PROT_IPEAK_HIGH_LEVEL_INCREMENT 0xEB73

/** tester {un8 = data} */
#define VE_REG_INV_PROT_IPEAK_DECREMENT 0xEB74

/** tester {un16 = data} */
#define VE_REG_INV_PROT_IPEAK_COUNT 0xEB75

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_RIPPLE_LEVEL_HIGH 0xEB76

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_RIPPLE_IS_HIGH_COUNT 0xEB77

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_RIPPLE_LEVEL2HIGH 0xEB78

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UBAT_RIPPLE_IS2HIGH_COUNT 0xEB79

/** tester {un8 = data} */
#define VE_REG_INV_PROT_TEMP_TRANS_WARNING_HIGH_C 0xEB7A

/** tester {un8 = data} */
#define VE_REG_INV_PROT_TEMP_TRANS2HIGH_C 0xEB7B

/**  {un16 = data} */
#define VE_REG_INV_PROT_UBAT_LEVEL_WARNING_LOW_CLEAR 0xEB7C

/** tester {un16 = data} */
#define VE_REG_INV_PROT_FAULT_RESTART_TIMEOUT 0xEB7D

/** tester {un16 = data} */
#define VE_REG_INV_ADC_UINV_GAIN 0xEB80

/** tester {un16 = data} */
#define VE_REG_INV_ADC_UBAT_GAIN 0xEB82

/** tester {un16 = data} */
#define VE_REG_INV_ADC_UTEMP_TRANSF_GAIN 0xEB83

/** tester {un16 = data} */
#define VE_REG_INV_ADC_UTEMP_FET_GAIN 0xEB84

/** tester {sn16 = data} */
#define VE_REG_INV_ADC_UINV_OFFSET 0xEB88

/** tester {sn16 = data} */
#define VE_REG_INV_ADC_UBAT_OFFSET 0xEB8A

/** tester {sn16 = data} */
#define VE_REG_INV_ADC_UTEMP_TRANS_OFFSET 0xEB8B

/** tester {sn16 = data} */
#define VE_REG_INV_ADC_UTEMP_FET_OFFSET 0xEB8C

/** tester {un16 = data} */
#define VE_REG_INV_PWM_DEBUG2 0xEB91

/** tester {un8 = data} */
#define VE_REG_INV_SER_TEXT_FRAME_PERIOD 0xEB92

/** tester {un16 = data} */
#define VE_REG_INV_PROT_UINV_LEVEL_HIGH_AT_START_UP 0xEB93

/**  {un16 = data} */
#define VE_REG_INV_NVM_SERIAL 0xEB98

/** typeNvmCommand */
#define VE_REG_INV_NVM_COMMAND 0xEB99

/** typeFanMode tester */
#define VE_REG_INV_FAN_MODE 0xEBA0

/** tester {un16 = data} */
#define VE_REG_INV_FAN_SPEED_MIN 0xEBA1

/** tester {un16 = data} */
#define VE_REG_INV_FAN_SPEED_MAX 0xEBA2

/** tester {un16 = data} */
#define VE_REG_INV_FAN_SPEED_PITCH 0xEBA3

/** tester {un16 = data} */
#define VE_REG_INV_FAN_TIME_PITCH 0xEBA4

/** tester {un16 = data} */
#define VE_REG_INV_FAN_SPEED_UP 0xEBA5

/** tester {un16 = data} */
#define VE_REG_INV_FAN_SPEED_DOWN 0xEBA6

/** tester {un8 = data} */
#define VE_REG_INV_FAN_TEMP_FET_LOW 0xEBA7

/** tester {un8 = data} */
#define VE_REG_INV_FAN_TEMP_FET_HIGH 0xEBA8

/** tester {un16 = data} */
#define VE_REG_INV_FAN_IINV_LOW 0xEBA9

/** tester {un16 = data} */
#define VE_REG_INV_FAN_IINV_HIGH 0xEBAA

/** tester {un8 = data} */
#define VE_REG_INV_FAN_TEMP_AMBIENT_LOW 0xEBAB

/** tester {un8 = data} */
#define VE_REG_INV_FAN_TEMP_AMBIENT_HIGH 0xEBAC

/** tester {un16 = data} */
#define VE_REG_INV_FAN_IINV_ON_COUNT 0xEBAD

/** tester {un16 = data} */
#define VE_REG_INV_FAN_TIME_KEEP_ON 0xEBAE

/** tester {un8 = data} */
#define VE_REG_INV_FAN_TEMP_TRANSF_LOW 0xEBAF

/** tester {un8 = data} */
#define VE_REG_INV_FAN_TEMP_TRANSF_HIGH 0xEBB0

/** sn16 readonly */
#define VE_REG_INV_WAVE_GET_MIN_MARGIN_WAVE_PHASE 0xEBFF

/** Blue Power Charger LED State {un32 = Blue Power Charger LED State} */
#define VE_REG_BPC_LED_STATE 0xE000

/** Low current mode {un8 = Low current mode, 0 = off, 1 = on, 2 = night mode} */
#define VE_REG_BPC_LOW_CURRENT_MODE 0xE001

/** Low current mode: time left {un32 = Low current mode: time left [1s]} */
#define VE_REG_BPC_LOW_CURRENT_MODE_TIME_LEFT 0xE002

/** Output offset {un16 = Output offset [0.01V]} */
#define VE_REG_BPC_TST_OUTPUT_OFFSET 0xEE50

/** Output gain {un16 = Output gain} */
#define VE_REG_BPC_TST_OUTPUT_GAIN 0xEE60

/** Raw pwm output value {un16 = Raw pwm output value, 0-1000} */
#define VE_REG_BPC_TST_OUTPUT_RAW 0xEE70

/**
 * Tester get current limiter active {un8 = Tester get current limiter active,
 * 0=no, 1=yes, 255= unknown/invalid;}
 */
#define VE_REG_BPC_TST_CURR_LIMITER_ACTIVE 0xEE7C

/** Tester is calibrated {un8 = Tester is calibrated, 0=no, 1=yes;} */
#define VE_REG_BPC_TST_IS_CALIBRATED 0xEE7E

/**
 * Tester get button . 0:released; 1:pressed {un8 = Tester get button .
 * 0:released; 1:pressed}
 */
#define VE_REG_BPC_TST_BUTTON 0xEE7F

/** Tester potmeter/encoder value {un8 = Tester potmeter/encoder value} */
#define VE_REG_MPPT_TST_GET_DIO 0xEE7E

/** Tester keypad analog scan value {un8 = Tester keypad analog scan value} */
#define VE_REG_MPPT_TST_GET_KEYBRD 0xEE7F

/** Tester get factory settings checksum, should be 0xAA55 if calibrated. */
#define VE_REG_PPP_TST_CHECKSUM 0xEE7E

#define VE_REG_PPP_TST_BUTTON 0xEE7F

/**
 * Lynx Ion number of shutdowns caused by error {un16 = Lynx Ion number of
 * shutdowns caused by error}
 */
#define VE_REG_LYNX_ION_SHUTDOWNS_DUE_ERROR 0xEEFC

/** Lynx Ion battery extended flags {un32 = Lynx Ion battery extended flags} */
#define VE_REG_LYNX_ION_FLAGS_EXT 0xEEFD

/** Lynx Ion last errors . {un8 = err0 : un8 = err1 : un8 = err2 : un8 = err3} */
#define VE_REG_LYNX_ION_LAST_ERROR 0xEEFE

/** Lynx Ion consumed AH (same as VE_REG_BMV_CE) */
#define VE_REG_LYNX_ION_CE 0xEEFF

/** Internal temperature. {un16 = Internal temperature. [0.01K]} */
#define VE_REG_LYNX_SHUNT_INTERNAL_TEMPERATURE 0xEE60

/** Use to send NACK on CAN bus to indicate invalid calibration values (no data) */
#define VE_REG_LYNX_SHUNT_CALIBRATION 0xEE61

/**
 *  {un32 = Energy from AcIn1 to Inverter [0.01kWh], 0xFFFFFFFF = Not Available,
 * This is the amount of energy before the charger (so without loses). The
 * internal resolution of these counters is roughly 0.0182kWh}
 */
#define VE_REG_ENERGY_FROM_ACIN1_TO_INVERTER 0xEEC0

/**
 *  {un32 = Energy from AcIn2 to Inverter [0.01kWh], 0xFFFFFFFF = Not Available,
 * This is the amount of energy before the charger (so without loses)}
 */
#define VE_REG_ENERGY_FROM_ACIN2_TO_INVERTER 0xEEC1

/**  {un32 = Energy from AcIn1 to AC-Out [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_ACIN1_TO_ACOUT 0xEEC2

/**  {un32 = Energy from AcIn2 to AC-Out [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_ACIN2_TO_ACOUT 0xEEC3

/**  {un32 = Energy from Inverter to AC-In1 [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_INVERTER_TO_ACIN1 0xEEC4

/**  {un32 = Energy from Inverter to AC-In2 [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_INVERTER_TO_ACIN2 0xEEC5

/**  {un32 = Energy from AC-out to AC-In1 [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_ACOUT_TO_ACIN1 0xEEC6

/**  {un32 = Energy from AC-out to AC-In2 [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_ACOUT_TO_ACIN2 0xEEC7

/**  {un32 = Energy from Inverter to AC-Out [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_INVERTER_TO_ACOUT 0xEEC8

/**  {un32 = Energy from AC-Out to Inverter [0.01kWh], 0xFFFFFFFF = Not Available} */
#define VE_REG_ENERGY_FROM_ACOUT_TO_INVERTER 0xEEC9

/**
 * Read / write. Reports / sets the maximum charge current in 0.1A. the unit is
 * to be compatible with the charger settings in 0xED. Vebus actually uses 1A.
 * {un16 = Read / write. Reports / sets the maximum charge current in 0.1A. the
 * unit is to be compatible with the charger settings in 0xED. Vebus actually
 * uses 1A.}
 */
#define VE_REG_MK2CAN_MAX_CHARGE_CURRENT 0xEEFE

/** Vebus error {un8 = Vebus error} */
#define VE_REG_MK2CAN_VEBUS_ERROR 0xEEFF

/**
 *               Tester dio pin value
 *               @remark value: B1=control, B0=mains
 *              {un8 = value}
 */
#define VE_REG_SCB_TST_GET_DIO 0xEE7C

/**
 *               Tester dip-switch value
 *               @remark value: bit mask B5..B0=dip switches 1..6
 *              {un8 = value}
 */
#define VE_REG_SCB_TST_GET_DIPSW 0xEE7E

/**
 * Tester rotary switch value value: bit mask
 * B7=update,B6=equalize,B5=remote,B4=power,B3..B0=rotary encoder {un8 = value}
 */
#define VE_REG_SCB_TST_GET_ROTARY 0xEE7F

/** Tester ambient light value {un16 = value} */
#define VE_REG_SRP_TST_GET_LDR 0xEE7C

/** Tester potmeter/encoder value {un16 = value} */
#define VE_REG_SRP_TST_GET_POT 0xEE7E

/** value: B2=setup (rear),B1=power,B0=encoder" */
#define VE_REG_SRP_TST_GET_SWITCH 0xEE7F

//[[[end]]]

/// @}
#endif
