#ifndef _VELIB_VECAN_PRODUCTS_H_
#define _VELIB_VECAN_PRODUCTS_H_

#include <velib/base/base.h>

/**
 * @ingroup VELIB_VECAN
 * @defgroup VELIB_VECAN_PRODUCTS	Product IDs
 */
/// @{

/*
 * note: Vebus itself uses 4 decimal number, the BCD version is used to let
 * the velib based tools print the number as mentioned on the product, hence
 *
 * !! DO NOT ADD NEW DEVICES BELOW 0xA000, RESERVED FOR VEBUS, to keep victron products ids unique !!
 */

/* 0x0200..0x0211:         , BMVs */
/* 0x0300..0x0300:  1 item,  MPPT charger */
/* 0xA000..0xA03F: 64 items, Skylla chargers */
/* 0xA040..0xA07F: 64 items, VE.Direct Solar chargers */
/* 0xA0C1..0xA0C1:  1 item,  Lithium Balancer */
/* 0xA0E0..0xA0FF: 32 items, SmartLithium batteries */
/* 0xA101..0xA11F: 31 items, VE.Can Solar chargers */
/* 0xA140..0xA15F: 32 items, Photovoltaic Inverters */
/* 0xA160..0xA160:  1 item,  General Tank sensor */
/* 0xA170..0xA17F: 16 items, VE.Direct remote panels */
/* 0xA180..0xA18F: 16 items, Misc. VE.Direct products (PPP, BLE dongle) */
/* 0xA190..0xA1AF: 32 items, (Builtin) bluetooth dongles */
/* 0xA200..0xA23F: 64 items, Phoenix inverters (models with VE.Direct bus and "MultiC" SW) */
/* 0xA300..0xA33F: 64 items, Blue Smart Chargers (Bluetooth LE) */
/* 0xA340..0xA37F: 64 items, Blue Power Chargers */
/* 0xB000..??????: ?? items, Non Victron batteries */
/*
 * Product id's for VeIf interfaces. 0xFE00 .. 0xFEFF (256)
 * These are not physical products but software components that can talk vregs.
 * In this range when: prodId & Mask = Base
 */

/*[[[cog
import vepy.codegenerator
vepy.codegenerator.codegen.defines("meanings:victronenergy:product.ids")
]]]*/

/* VE.Net Panel */
#define VE_PROD_ID_VENET_VPN 0x0001

/* VE.Net Battery Controller */
#define VE_PROD_ID_VENET_VBC 0x0002

/* VE.Net to VE 9bit RS485 Converter (formerly known as VVU) */
#define VE_PROD_ID_VENET_VVC 0x0003

/* VE.Net VE.Net DC Converter */
#define VE_PROD_ID_VENET_VCC 0x0004

/* VE.Net Connectivity Module */
#define VE_PROD_ID_VENET_VCM 0x0005

/* VE.Net Generator Module */
#define VE_PROD_ID_VENET_VGM 0x0006

/* VE.Net Resistive Sensor */
#define VE_PROD_ID_VENET_VRS 0x0007

/* Free Technics software */
#define VE_PROD_ID_VENET_FT 0x0008

/* VE.Net Battery controller with GMDSS Software */
#define VE_PROD_ID_VENET_VBC_GMDSS 0x0009

/* VE.Net Panel with GMDSS Software */
#define VE_PROD_ID_VENET_VPN_GMDSS 0x000A

/* VE.Net Blue Power Panel */
#define VE_PROD_ID_VENET_BPP 0x000B

/* VE.Net Battery Controller (48V version) */
#define VE_PROD_ID_VENET_VBC_48 0x000C

/* VE.Net to VE.Bus Converter */
#define VE_PROD_ID_VENET_VVC2 0x000D

/* VE.Net Battery Controller (144V version) */
#define VE_PROD_ID_VENET_VBC_144 0x000E

/* VE.Net Battery Controller (Combined 12/24/48V version) */
#define VE_PROD_ID_VENET_VBC2 0x000F

/* VE.Net Battery Controller (V2 hardware of the 144V model) */
#define VE_PROD_ID_VENET_VBC2_144 0x0010

/* VE.Net Lynx shunt */
#define VE_PROD_ID_VENET_LYNX 0x0011

/* BMV CAN converter */
#define VE_PROD_ID_VECAN_BMV 0x0100

/* Skylla-i Remote Panel */
#define VE_PROD_ID_VECAN_SRP 0x0101

/* Hybrid Panel */
#define VE_PROD_ID_VECAN_VHP 0x0102

/* MK2NMEA - vebus to NMEA 2000 */
#define VE_PROD_ID_VECAN_MK2NMEA 0x0103

/* Skylla-i charger 24V 100A 1+1 output */
#define VE_PROD_ID_VECAN_SKYLLA_I_24V_100A_1OUT 0x0104

/* Skylla-i charger 24V 80A 1+1 output */
#define VE_PROD_ID_VECAN_SKYLLA_I_24V_80A_1OUT 0x0105

/* Skylla-i charger 24V 100A 3 outputs */
#define VE_PROD_ID_VECAN_SKYLLA_I_24V_100A_3OUT 0x0106

/* Skylla-i charger 24V 80A 3 outputs */
#define VE_PROD_ID_VECAN_SKYLLA_I_24V_80A_3OUT 0x0107

/* BlueSolar Charger MPPT 150/70 (1x 12V..48V 70A charge output / 1x 145V 50A panel input) */
#define VE_PROD_ID_VECAN_BLUE_SOLAR_MPPT_70A 0x0108

/* Ion Controller */
#define VE_PROD_ID_VECAN_LIC 0x0140

/* Lynx Shunt */
#define VE_PROD_ID_VECAN_LYNX_SHUNT 0x0141

/* Lynx Ion (MG Electronics) */
#define VE_PROD_ID_VECAN_LYNX_ION 0x0142

/* BMV-600S */
#define VE_PROD_ID_BMV600S 0x0200

/* BMV-602S */
#define VE_PROD_ID_BMV602S 0x0201

/* BMV-600HS */
#define VE_PROD_ID_BMV600HS 0x0202

/* BMV-700 */
#define VE_PROD_ID_BMV700 0x0203

/* BMV-702 */
#define VE_PROD_ID_BMV702 0x0204

/* BMV-700H */
#define VE_PROD_ID_BMV700H 0x0205

/* BMV PCBA test firmware */
#define VE_PROD_ID_BMVTEST 0x0211

/* BlueSolar Charger MPPT 70/15 (1x 12V..24V 15A charge output / 1x 75V panel input / 1x 15A load output / 16kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_70_15 0x0300

/* Remote panel */
#define VE_PROD_ID_VEBUS_REMOTE_PANEL_9912 0x1110

/* Remote panel 20MHz */
#define VE_PROD_ID_VEBUS_REMOTE_PANEL_20MHZ_9915 0x1120

/* Remote panel Dongle 20MHz */
#define VE_PROD_ID_VEBUS_REMOTE_PANEL_DONGLE_20MHZ_9915 0x1121

/* MK2 20Mhz */
#define VE_PROD_ID_VEBUS_MK2_20MHZ_9915 0x1130

/* MK2 Dongle 20Mhz */
#define VE_PROD_ID_VEBUS_MK2_DONGLE_20MHZ_9915 0x1131

/* VE.Bus Resetter (based on MK2) 20 Mhz */
#define VE_PROD_ID_VEBUS_VE_BUS_RESETTER__BASED_ON_MK2__20_MHZ_9915 0x1132

/* MK2 tachometer 20Mhz */
#define VE_PROD_ID_VEBUS_MK2_TACHOMETER_20MHZ_9916 0x1140

/* BMS 20Mhz */
#define VE_PROD_VEBUS_BMS 0x1145

/* Solar switch box */
#define VE_PROD_ID_VEBUS_SOLAR_SWITCH_BOX_9918 0x1150

/* USB VEBus grabber */
#define VE_PROD_ID_VEBUS_USB_VEBUS_GRABBER_9919 0x1160

/* MK3 */
#define VE_PROD_ID_MK3 0x1170

/* Phoenix Charger 12/100 */
#define VE_PROD_ID_VEBUS_PHOENIX_CHARGER_12_100_9911 0x1421

/* Phoenix Charger 12/200 */
#define VE_PROD_ID_VEBUS_PHOENIX_CHARGER_12_200_9911 0x1422

/* Phoenix Charger 24/50 */
#define VE_PROD_ID_VEBUS_PHOENIX_CHARGER_24_50_9911 0x1431

/* Phoenix Charger 24/100 */
#define VE_PROD_ID_VEBUS_PHOENIX_CHARGER_24_100_9911 0x1432

/* Phoenix Multi 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_12V_FULL_POWER_9901 0x1700

/* Phoenix Multi 12V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_12V_HALF_POWER_9901 0x1701

/* Phoenix MultiPlus 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_12V_FULL_POWER_9901 0x1702

/* MultiCompact 12V low power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_12V_LOW_POWER_9900 0x1703

/* MultiCompact 12V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_12V_MEDIUM_POWER_9900 0x1704

/* MultiCompact 12V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_12V_HIGH_POWER_9900 0x1705

/* MultiCompactPlus 12V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_12V_HIGH_POWER_9900 0x1706

/* MultiCompactPlus 12V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_12V_MEDIUM_POWER_9900 0x1707

/* Phoenix Multi 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_24V_FULL_POWER_9901 0x1710

/* Phoenix Multi 24V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_24V_HALF_POWER_9901 0x1711

/* Phoenix MultiPlus 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_24V_FULL_POWER_9901 0x1712

/* MultiCompact 24V low power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_24V_LOW_POWER_9900 0x1713

/* MultiCompact 24V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_24V_MEDIUM_POWER_9900 0x1714

/* MultiCompact 24V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_24V_HIGH_POWER_9900 0x1715

/* MultiCompactPlus 24V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_24V_HIGH_POWER_9900 0x1716

/* MultiCompactPlus 24V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_24V_MEDIUM_POWER_9900 0x1717

/* Phoenix Multi 120 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_12V_FULL_POWER_9901 0x1730

/* Phoenix Multi 120 12V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_12V_HALF_POWER_9901 0x1731

/* Phoenix MultiPlus 120 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_12V_FULL_POWER_9901 0x1732

/* Phoenix Multi 120 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_24V_FULL_POWER_9901 0x1740

/* Phoenix Multi 120 24V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_24V_HALF_POWER_9901 0x1741

/* Phoenix MultiPlus 120 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_24V_FULL_POWER_9901 0x1742

/* Phoenix Multi 48V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_48V_FULL_POWER_9901 0x1750

/* Phoenix Multi 48V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_48V_HALF_POWER_9901 0x1751

/* Phoenix MultiPlus 48V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_48V_FULL_POWER_9901 0x1752

/* Phoenix Multi 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_12V_FULL_POWER_9906 0x1800

/* Phoenix Multi 12V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_12V_HALF_POWER_9906 0x1801

/* Phoenix MultiPlus 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_12V_FULL_POWER_9906 0x1802

/* MultiCompact 12V low power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_12V_LOW_POWER_9902 0x1803

/* MultiCompact 12V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_12V_MEDIUM_POWER_9902 0x1804

/* MultiCompact 12V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_12V_HIGH_POWER_9902 0x1805

/* MultiCompactPlus 12V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_12V_HIGH_POWER_9902 0x1806

/* MultiCompactPlus 12V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_12V_MEDIUM_POWER_9902 0x1807

/* Phoenix MultiPlus 12V/2000 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_12V_2000_9906 0x1808

/* Phoenix MultiPlus 12V/3000 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_12V_3000_9906 0x1809

/* Phoenix Multi 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_24V_FULL_POWER_9906 0x1810

/* Phoenix Multi 24V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_24V_HALF_POWER_9906 0x1811

/* Phoenix MultiPlus 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_24V_FULL_POWER_9906 0x1812

/* MultiCompact 24V low power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_24V_LOW_POWER_9902 0x1813

/* MultiCompact 24V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_24V_MEDIUM_POWER_9902 0x1814

/* MultiCompact 24V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACT_24V_HIGH_POWER_9902 0x1815

/* MultiCompactPlus 24V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_24V_HIGH_POWER_9902 0x1816

/* MultiCompactPlus 24V medium power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_24V_MEDIUM_POWER_9902 0x1817

/* Phoenix MultiPlus 24V/2000 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_24V_2000_9906 0x1818

/* Phoenix Multi 120 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_12V_FULL_POWER_9906 0x1830

/* Phoenix Multi 120 12V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_12V_HALF_POWER_9906 0x1831

/* Phoenix MultiPlus 120 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_12V_FULL_POWER_9906 0x1832

/* MultiCompactPlus 120 12V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_120_12V_HIGH_POWER_9906 0x1836

/* Phoenix MultiPlus 120 12V/3000 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_12V_3000_9906 0x1839

/* Phoenix Multi 120 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_24V_FULL_POWER_9906 0x1840

/* Phoenix Multi 120 24V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_120_24V_HALF_POWER_9906 0x1841

/* Phoenix MultiPlus 120 24V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_24V_FULL_POWER_9906 0x1842

/* MultiCompactPlus 120 24V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_120_24V_HIGH_POWER_9906 0x1846

/* Phoenix Multi 48V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_48V_FULL_POWER_9906 0x1850

/* Phoenix Multi 48V half power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_48V_HALF_POWER_9906 0x1851

/* Phoenix MultiPlus 48V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_48V_FULL_POWER_9906 0x1852

/* MultiCompactPlus 48V high power */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_48V_HIGH_POWER_9906 0x1856

/* Phoenix MultiPlus 120 48V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_48V_FULL_POWER_9906 0x1862

/* MultiCompactPlus 12V 2K */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_12V_2K_9906 0x1871

/* MultiCompactPlus 24V 2K */
#define VE_PROD_ID_VEBUS_MULTICOMPACTPLUS_24V_2K_9906 0x1872

/* MultiPlus 12/3000/120-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_3000_120_50_9906 0x1900

/* MultiPlus 12/3000/120-30 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_3000_120_30_9906 0x1901

/* Phoenix MultiPlus 12V full power */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_12V_FULL_POWER 0x1902

/* Phoenix Multi Compact 12/800/35-16 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_COMPACT_12_800_35_16_9906 0x1903

/* MultiPlus Compact 12/1600/70-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_1600_70_16_9906 0x1906

/* MultiPlus Compact 12/1200/50-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_1200_50_16_9906 0x1907

/* MultiPlus Compact 12/2000/80-30 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_2000_80_30_9906 0x1908

/* MultiPlus 12/3000/120-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_3000_120_16_9906 0x1909

/* MultiPlus 24/3000/70-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_3000_70_50_9906 0x1910

/* MultiPlus 24/3000/70-30 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_3000_70_30_9906 0x1911

/* MultiPlus 24/3000/70-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_3000_70_16_9906 0x1912

/* Phoenix Multi Compact 24/800/16-16 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTI_COMPACT_24_800_16_16_9906 0x1913

/* MultiPlus Compact 24/1600/40-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_1600_40_16_9906 0x1916

/* MultiPlus Compact 24/1200/25-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_1200_25_16_9906 0x1917

/* MultiPlus Compact 24/2000/50-30 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_2000_50_30_9906 0x1918

/* MultiPlus 48/3000/35-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_3000_35_50_9906 0x1920

/* MultiPlus 48/3000/35-30 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_3000_35_30_9906 0x1921

/* MultiPlus 48/3000/35-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_3000_35_16_9906 0x1922

/* Quattro 12/5000/200-2x30 */
#define VE_PROD_ID_VEBUS_QUATTRO_12_5000_200_2X30_9906 0x1930

/* Quattro 12/3000/120-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_12_3000_120_50_30_9906 0x1931

/* Quattro 12/5000/200-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_12_5000_200_50_30_9906 0x1932

/* Quattro 12/5000/220-2x75 */
#define VE_PROD_ID_VEBUS_QUATTRO_12_5000_220_2X75_9906 0x1933

/* Quattro 24/5000/120-2x30 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_2X30_9906 0x1940

/* Quattro 24/3000/70-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_3000_70_50_30_9906 0x1941

/* Quattro 24/5000/120-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_50_30_9906 0x1942

/* Quattro 24/8000/200-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_8000_200_2X100_9906 0x1943

/* Quattro 24/5000/120-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_2X100_9906 0x1948

/* MultiPlus 24/5000/120-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_5000_120_50_9906 0x1949

/* Quattro 48/5000/70-2x30 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_5000_70_2X30_9906 0x1950

/* Quattro 48/5000/70-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_5000_70_50_30_9906 0x1952

/* Quattro 48/10000/140-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_10000_140_2X100_9906 0x1953

/* Quattro 48/8000/110-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_8000_110_2X100_9906 0x1954

/* Quattro 48/5000/70-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_5000_70_2X100_9906 0x1958

/* MultiPlus 48/5000/70-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_5000_70_50_9906 0x1959

/* MultiPlus 12/3000/120-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_3000_120_50_120V_9906 0x2002

/* MultiPlus Compact 12/2000/80-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_2000_80_50_120V_9906 0x2008

/* Phoenix MultiPlus 120 12V/3000 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_12V_3000 0x2009

/* MultiPlus 24/3000/70-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_3000_70_50_120V_9906 0x2012

/* MultiPlus Compact 24/2000/50-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_2000_50_50_120V_9906 0x2018

/* Phoenix MultiPlus 120 48V/3000 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_48V_3000_9906 0x2022

/* Quattro 24/5000/120-2x100 120V */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_2X100_120V_9906 0x2048

/* Quattro 48/3000/35-2x50 120V */
#define VE_PROD_ID_VEBUS_QUATTRO_48_3000_35_2X50_120V_9906 0x2051

/* Quattro 48/5000/70-2x100 120V */
#define VE_PROD_ID_VEBUS_QUATTRO_48_5000_70_2X100_120V_9906 0x2053

/* Phoenix MultiPlus 120 48V/5000 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_48V_5000_9906 0x2059

/* Phoenix 12/3000/120-50-120/240V */
#define VE_PROD_ID_VEBUS_PHOENIX_12_3000_120_50_120_240V_9906 0x2060

/* MultiPlus Compact 12/2000/80-50(30)-120/240V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_2000_80_50_30__120_240V_9906 0x2062

/* Quattro 24/5000/120-2x60-120/240V */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_2X60_120_240V_9906 0x2071

/* MultiPlus Compact 24/2000/50-50(30)-120/240V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_2000_50_50_30__120_240V_9906 0x2072

/* Phoenix MultiPlus 120/240 48V/3000 with 50A AC relais */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_120_240_48V_3000_WITH_50A_AC_RELAIS_9906 0x2080

/* Phoenix HF */
#define VE_PROD_ID_VEBUS_PHOENIX_HF_9915 0x2101

/* Phoenix 12/800 */
#define VE_PROD_ID_VEBUS_PHOENIX_12_800 0x2403

/* Phoenix 12/1200 */
#define VE_PROD_ID_VEBUS_PHOENIX_12_1200 0x2404

/* Phoenix 24/800 */
#define VE_PROD_ID_VEBUS_PHOENIX_24_800 0x2413

/* Phoenix 24/1200 */
#define VE_PROD_ID_VEBUS_PHOENIX_24_1200 0x2414

/* Phoenix 48/800 */
#define VE_PROD_ID_VEBUS_PHOENIX_48_800 0x2423

/* Phoenix 48/1200 */
#define VE_PROD_ID_VEBUS_PHOENIX_48_1200 0x2424

/* Phoenix 12/800 120V */
#define VE_PROD_ID_VEBUS_PHOENIX_12_800_120V 0x2453

/* Phoenix 12/1200 120V */
#define VE_PROD_ID_VEBUS_PHOENIX_12_1200_120V 0x2454

/* Phoenix 24/800 120V */
#define VE_PROD_ID_VEBUS_PHOENIX_24_800_120V 0x2463

/* Phoenix 24/1200 120V */
#define VE_PROD_ID_VEBUS_PHOENIX_24_1200_120V 0x2464

/* Phoenix 48/800 120V */
#define VE_PROD_ID_VEBUS_PHOENIX_48_800_120V 0x2473

/* Phoenix 48/1200 120V */
#define VE_PROD_ID_VEBUS_PHOENIX_48_1200_120V 0x2474

/* MultiPlus 12/3000/120-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_3000_120_50 0x2600

/* Phoenix Multi Compact 12/800/35-16 */
#define VE_PROD_ID_VEBUS_PHOENIX_MULTIPLUS_COMPACT_12_800_35_15 0x2603

/* MultiPlus Compact 12/1600/70-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_1600_70_16 0x2606

/* MultiPlus Compact 12/1200/50-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_1200_50_16 0x2607

/* MultiPlus Compact 12/2000/80-30 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_2000_80_30 0x2608

/* MultiPlus 12/3000/120-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_3000_120_16 0x2609

/* MultiPlus 24/3000/70-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_3000_70_50 0x2610

/* MultiPlus 24/3000/70-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_3000_70_16 0x2612

/* Phoenix Multi Compact 24/800/16-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_800_16_16 0x2613

/* MultiPlus 24/5000/120-100 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_5000_120_100 0x2614

/* MultiPlus Compact 24/1600/40-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_1600_40_16 0x2616

/* MultiPlus Compact 24/1200/25-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_1200_25_16 0x2617

/* MultiPlus Compact 24/2000/50-30 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_2000_50_30 0x2618

/* MultiPlus 48/3000/35-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_3000_35_50 0x2620

/* MultiPlus 48/3000/35-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_3000_35_16 0x2622

/* MultiPlus 48/5000/70-100 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_5000_70_100 0x2624

/* Quattro 12/3000/120-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_12_3000_120_50_30 0x2631

/* Quattro 12/5000/220-2x75 */
#define VE_PROD_ID_VEBUS_QUATTRO_12_5000_220 0x2633

/* Quattro 12/3000/120-2x50 */
#define VE_PROD_ID_VEBUS_QUATTRO_12_3000_120 0x2634

/* Quattro 24/3000/70-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_3000_70_50_30 0x2641

/* Quattro 24/5000/120-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_50_30 0x2642

/* Quattro 24/8000/200-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_8000_200_100_100 0x2643

/* Quattro 24/3000/70-2x50 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_3000_70_50_50 0x2644

/* Quattro 24/5000/120-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_100_100 0x2648

/* MultiPlus 24/5000/120-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_5000_120_50 0x2649

/* Quattro 48/5000/70-50/30 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_5000_70_50_30 0x2652

/* Quattro 48/10000/140-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_10000_140_100_100 0x2653

/* Quattro 48/8000/110-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_8000_110_100_100 0x2654

/* Quattro 48/8000/110-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_8000_110_100_100_REV2 0x2655

/* Quattro 48/5000/70-2x100-S */
#define VE_PROD_ID_VEBUS_QUATTRO_S_48_5000_70_100_100 0x2657

/* Quattro 48/5000/70-2x100 */
#define VE_PROD_ID_VEBUS_QUATTRO_48_5000_70_100_100 0x2658

/* MultiPlus 48/5000/70-50 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_5000_70_50 0x2659

/* MultiPlus 12/500/20-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_500_20_16 0x2660

/* MultiPlus 12/800/20-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_800_20_16 0x2661

/* MultiPlus 24/500/10-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_500_10_16 0x2665

/* MultiPlus 24/800/10-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_800_10_16 0x2666

/* MultiPlus 48/500/6-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_500_6_16 0x2670

/* MultiPlus 48/800/6-16 */
#define VE_PROD_ID_VEBUS_MULTIPLUS_48_800_6_16 0x2671

/* MultiPlus 12/3000/120-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_12_3000_120_50_120V 0x2702

/* MultiPlus Compact 12/2000/80-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_12_2000_80_50_120V 0x2708

/* MultiPlus 24/3000/70-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_24_3000_70_50_120V 0x2712

/* MultiPlus Compact 24/2000/50-50 120V */
#define VE_PROD_ID_VEBUS_MULTIPLUS_COMPACT_24_2000_50_50_120V 0x2718

/* Quattro 12/5000/120-2x100 120V */
#define VE_PROD_ID_VEBUS_QUATTRO_12_5000_120_100_100_120V 0x2733

/* Quattro 24/5000/120-2x100 120V */
#define VE_PROD_ID_VEBUS_QUATTRO_24_5000_120_100_100_120V 0x2748

/* Quattro 48/3000/35-2x50 120V */
#define VE_PROD_ID_VEBUS_QUATTRO_48_3000_35_50_50_120V 0x2751

/* Quattro 48/5000/70-2x100 120V */
#define VE_PROD_ID_VEBUS_QUATTRO_48_5000_70_100_100_120V 0x2753

/* Skylla-IP44 control board (generic family id / bootloader mode) */
#define VE_PROD_ID_VECAN_SKYLLA_IP44 0xA000

/* Skylla-IP44 12V/60A/1 output,  input voltage 220-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_12V_60A_1OUT_230V 0xA001

/* Skylla-IP44 12V/60A/3 outputs, input voltage 220-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_12V_60A_3OUT_230V 0xA002

/* Skylla-IP44 12V/60A/1 output,  input voltage 120-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_12V_60A_1OUT_FM 0xA003

/* Skylla-IP44 12V/60A/3 outputs, input voltage 120-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_12V_60A_3OUT_FM 0xA004

/* Skylla-IP44 24V/30A/1 output,  input voltage 220-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_24V_30A_1OUT_230V 0xA005

/* Skylla-IP44 24V/30A/3 outputs, input voltage 220-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_24V_30A_3OUT_230V 0xA006

/* Skylla-IP44 24V/30A/1 output,  input voltage 120-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_24V_30A_1OUT_FM 0xA007

/* Skylla-IP44 24V/30A/3 outputs, input voltage 120-240VAC/50-60Hz */
#define VE_PROD_ID_VECAN_SKYLLA_IP44_24V_30A_3OUT_FM 0xA008

/* BlueSolar Charger MPPT 75/50 (1x 12V..24V 50A charge output / 1x 75V panel input / 32kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_75_50 0xA040

/* BlueSolar Charger MPPT 150/35 (1x 12V..48V 35A charge output / 1x 150V panel input / 32kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_150_35 0xA041

/* BlueSolar Charger MPPT 75/15 (1x 12V..24V 15A charge output / 1x 75V panel input / 1x 15A load output / 32kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_75_15 0xA042

/* BlueSolar Charger MPPT 100/15 (1x 12V..24V 15A charge output / 1x 100V panel input / 1x 15A load output / 32kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_100_15 0xA043

/* BlueSolar Charger MPPT 100/30 (1x 12V..24V 30A charge output / 1x 100V panel input / 32kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_100_30 0xA044

/* BlueSolar Charger MPPT 100/50 (1x 12V..24V 50A charge output / 1x 100V panel input / 32kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_100_50 0xA045

/* BlueSolar Charger MPPT 150/70 (1x 12V..48V 70A charge output / 1x 150V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_150_70 0xA046

/* BlueSolar Charger MPPT 150/100 (1x 12V..48V 100A charge output / 1x 150V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_150_100 0xA047

/* BlueSolar Charger MPPT 75/50 (1x 12V..24V 50A charge output / 1x 75V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_75_50_REV2 0xA048

/* BlueSolar Charger MPPT 100/50 (1x 12V..24V 50A charge output / 1x 100V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_100_50_REV2 0xA049

/* BlueSolar Charger MPPT 100/30 (1x 12V..24V 30A charge output / 1x 100V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_100_30_REV2 0xA04A

/* BlueSolar Charger MPPT 150/35 (1x 12V..48V 35A charge output / 1x 150V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_150_35_REV2 0xA04B

/* BlueSolar Charger MPPT 75/10 (1x 12V..24V 10A charge output / 1x 75V panel input / 1x 10A load output / 32kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_75_10 0xA04C

/* BlueSolar Charger MPPT 150/45 (1x 12V..48V 45A charge output / 1x 150V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_150_45 0xA04D

/* BlueSolar Charger MPPT 150/60 (1x 12V..48V 60A charge output / 1x 150V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_150_60 0xA04E

/* BlueSolar Charger MPPT 150/85 (1x 12V..48V 85A charge output / 1x 150V panel input / 60kB micro) */
#define VE_PROD_ID_BLUE_SOLAR_MPPT_150_85 0xA04F

/* SmartSolar Charger MPPT 250/100 (1x 12V..48V 100A charge output / 1x 250V panel input / 64kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_250_100 0xA050

/* SmartSolar Charger MPPT 150/100 (1x 12V..48V 100A charge output / 1x 150V panel input / 60kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_150_100 0xA051

/* SmartSolar Charger MPPT 150/85 (1x 12V..48V 85A charge output / 1x 150V panel input / 60kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_150_85 0xA052

/* SmartSolar Charger MPPT 75/15 (1x 12V..24V 15A charge output / 1x 75V panel input / 1x 15A load output / 64kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_75_15 0xA053

/* SmartSolar Charger MPPT 75/10 (1x 12V..24V 10A charge output / 1x 75V panel input / 1x 10A load output / 64kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_75_10 0xA054

/* SmartSolar Charger MPPT 100/15 (1x 12V..24V 15A charge output / 1x 100V panel input / 1x 15A load output / 64kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_100_15 0xA055

/* SmartSolar Charger MPPT 100/30 (1x 12V..24V 30A charge output / 1x 100V panel input / 64kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_100_30 0xA056

/* SmartSolar Charger MPPT 100/50 (1x 12V..24V 50A charge output / 1x 100V panel input / 64kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_100_50 0xA057

/* SmartSolar Charger MPPT 150/35 (1x 12V..24V 35A charge output / 1x 150V panel input / 64kB micro / bluetooth) */
#define VE_PROD_ID_SMART_SOLAR_MPPT_150_35 0xA058

/* Lithium Battery Balancer */
#define VE_PROD_ID_LITHIUM_BALANCER 0xA0C1

/* Smart Lithium Battery 12.8V/90Ah */
#define VE_PROD_ID_SMART_LITHIUM_12V_90AH 0xA0E0

/* Smart Lithium Battery 12.8V/60Ah */
#define VE_PROD_ID_SMART_LITHIUM_12V_60AH 0xA0E1

/* BlueSolar Remote Panel */
#define VE_PROD_ID_VECAN_BSRP 0xA100

/* BlueSolar Charger MPPT 150/85 (1x 12V..48V 85A charge output / 1x 145V 75A panel input) */
#define VE_PROD_ID_VECAN_BLUE_SOLAR_MPPT_85A 0xA101

/* MK2NMEA - vebus to NMEA 2000 (version 2) */
#define VE_PROD_ID_VECAN_MK2NMEA_REV2 0xA120

/* VE.Direct CAN converter (version 2) */
#define VE_PROD_ID_VECAN_VEDIRECT 0xA121

/* Lynx Ion + Shunt (MG Electronics) */
#define VE_PROD_ID_VECAN_LYNX_ION_SHUNT 0xA130

/* Measured by Quby sensors */
#define VE_PROD_ID_PV_INVERTER_QWACS 0xA140

/* Measured by VE.Bus AC current sensors */
#define VE_PROD_ID_PV_INVERTER_VEBUS 0xA141

/* Fronius solar inverters */
#define VE_PROD_ID_PV_INVERTER_FRONIUS 0xA142

/* Generic tank sensor (VE.Can/NMEA2000) */
#define VE_PROD_ID_TANK_SENSOR 0xA160

/* Generic tank input */
#define VE_PROD_ID_TANK_SENSOR_INPUT 0xA161

/* Generic temperature input */
#define VE_PROD_ID_TEMPERATURE_SENSOR_INPUT 0xA162

/* VE.Direct MPPT control */
#define VE_PROD_ID_MPPT_CONTROL 0xA170

/* VE.Direct MPPT control test firmware */
#define VE_PROD_ID_MPPT_CONTROL_TEST 0xA171

/* Peak Power Pack 12V 8Ah */
#define VE_PROD_ID_VEDIRECT_PPP_12V_8AH 0xA180

/* Peak Power Pack test firmware */
#define VE_PROD_ID_VEDIRECT_PPP_TEST 0xA181

/* VE.Direct Bluetooth Smart Dongle */
#define VE_PROD_ID_VEDIRECT_SMART_DONGLE 0xA182

/* Bootloader for softdevice v7 */
#define VE_PROD_ID_VEDIRECT_DONGLE_BL_SD_V7 0xA183

/* Virtual id for v1 legacy dongle */
#define VE_PROD_ID_VEDIRECT_DONGLE_LEGACY_V1 0xA184

/* Peak Power Pack 12V 20Ah */
#define VE_PROD_ID_VEDIRECT_PPP_12V_20AH 0xA185

/* Peak Power Pack 12V 30Ah */
#define VE_PROD_ID_VEDIRECT_PPP_12V_30AH 0xA186

/* Peak Power Pack 12V 40Ah */
#define VE_PROD_ID_VEDIRECT_PPP_12V_40AH 0xA187

/* SmartSolar Bluetooth Interface */
#define VE_PROD_ID_SMARTSOLAR_DONGLE 0xA190

/* unspecified spec */
#define VE_PROD_ID_PHOENIX_INVERTER 0xA200

/* Phoenix Inverter 12V 250VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_12V_250VA 0xA201

/* Phoenix Inverter 24V 250VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_24V_250VA 0xA202

/* Phoenix Inverter 48V 250VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_48V_250VA 0xA204

/* Phoenix Inverter 12V 375VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_12V_375VA 0xA211

/* Phoenix Inverter 24V 375VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_24V_375VA 0xA212

/* Phoenix Inverter 48V 375VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_48V_375VA 0xA214

/* Phoenix Inverter 12V 500VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_12V_500VA 0xA221

/* Phoenix Inverter 24V 500VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_24V_500VA 0xA222

/* Phoenix Inverter 48V 500VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_48V_500VA 0xA224

/* Phoenix Inverter 12V 250VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_12V_250VA_64K 0xA231

/* Phoenix Inverter 24V 250VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_24V_250VA_64K 0xA232

/* Phoenix Inverter 48V 250VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_48V_250VA_64K 0xA234

/* Phoenix Inverter 12V 375VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_12V_375VA_64K 0xA241

/* Phoenix Inverter 24V 375VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_24V_375VA_64K 0xA242

/* Phoenix Inverter 48V 375VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_48V_375VA_64K 0xA244

/* Phoenix Inverter 12V 500VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_12V_500VA_64K 0xA251

/* Phoenix Inverter 24V 500VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_24V_500VA_64K 0xA252

/* Phoenix Inverter 48V 500VA 230V */
#define VE_PROD_ID_PHOENIX_INVERTER_48V_500VA_64K 0xA254

/* Generic id */
#define VE_PROD_ID_BSC 0xA300

/* Blue Smart IP65 Charger 12|10 */
#define VE_PROD_ID_BSC_IP65_12_10 0xA301

/* Blue Smart IP65 Charger 12|15 */
#define VE_PROD_ID_BSC_IP65_12_15 0xA302

/* Blue Smart IP65 Charger 24|8 */
#define VE_PROD_ID_BSC_IP65_24_8 0xA303

/* Blue Smart IP65 Charger 12|5 */
#define VE_PROD_ID_BSC_IP65_12_5 0xA304

/* Blue Smart IP65 Charger 12|7 */
#define VE_PROD_ID_BSC_IP65_12_7 0xA305

/* Blue Smart IP65 Charger 24|5 */
#define VE_PROD_ID_BSC_IP65_24_5 0xA306

/* Blue Smart IP65 Charger 12|4 */
#define VE_PROD_ID_BSC_IP65_12_4 0xA307

/* Blue Smart IP67 Charger 12|7 */
#define VE_PROD_ID_BSC_IP67_12_7 0xA310

/* Blue Smart IP67 Charger 12|13 */
#define VE_PROD_ID_BSC_IP67_12_13 0xA311

/* Blue Smart IP67 Charger 24|5 */
#define VE_PROD_ID_BSC_IP67_24_5 0xA312

/* Blue Smart IP67 Charger 12|17 */
#define VE_PROD_ID_BSC_IP67_12_17 0xA313

/* Blue Smart IP67 Charger 12|25 */
#define VE_PROD_ID_BSC_IP67_12_25 0xA314

/* Blue Smart IP67 Charger 24|8 */
#define VE_PROD_ID_BSC_IP67_24_8 0xA315

/* Blue Smart IP67 Charger 24|12 */
#define VE_PROD_ID_BSC_IP67_24_12 0xA316

/* Blue Smart IP22 Charger 12|15 (1) */
#define VE_PROD_ID_BSC_IP22_12_15_1 0xA320

/* Blue Smart IP22 Charger 12|15 (3) */
#define VE_PROD_ID_BSC_IP22_12_15_3 0xA321

/* Blue Smart IP22 Charger 12|20 (1) */
#define VE_PROD_ID_BSC_IP22_12_20_1 0xA322

/* Blue Smart IP22 Charger 12|20 (3) */
#define VE_PROD_ID_BSC_IP22_12_20_3 0xA323

/* Blue Smart IP22 Charger 12|30 (1) */
#define VE_PROD_ID_BSC_IP22_12_30_1 0xA324

/* Blue Smart IP22 Charger 12|30 (3) */
#define VE_PROD_ID_BSC_IP22_12_30_3 0xA325

/* Blue Smart IP22 Charger 24|8 (1) */
#define VE_PROD_ID_BSC_IP22_24_8_1 0xA326

/* Blue Smart IP22 Charger 24|8 (3) */
#define VE_PROD_ID_BSC_IP22_24_8_3 0xA327

/* Blue Smart IP22 Charger 24|12 (1) */
#define VE_PROD_ID_BSC_IP22_24_12_1 0xA328

/* Blue Smart IP22 Charger 24|12 (3) */
#define VE_PROD_ID_BSC_IP22_24_12_3 0xA329

/* Blue Smart IP22 Charger 24|16 (1) */
#define VE_PROD_ID_BSC_IP22_24_16_1 0xA32A

/* Blue Smart IP22 Charger 24|16 (3) */
#define VE_PROD_ID_BSC_IP22_24_16_3 0xA32B

/* Generic id */
#define VE_PROD_ID_BPC 0xA340

/* Blue Power IP65 Charger 12|10 */
#define VE_PROD_ID_BPC_IP65_12_10 0xA341

/* Blue Power IP65 Charger 12|15 */
#define VE_PROD_ID_BPC_IP65_12_15 0xA342

/* Blue Power IP65 Charger 24|8 */
#define VE_PROD_ID_BPC_IP65_24_8 0xA343

/* Blue Power IP65 Charger 12|5 */
#define VE_PROD_ID_BPC_IP65_12_5 0xA344

/* Blue Power IP65 Charger 12|7 */
#define VE_PROD_ID_BPC_IP65_12_7 0xA345

/* Blue Power IP65 Charger 24|5 */
#define VE_PROD_ID_BPC_IP65_24_5 0xA346

/* Valence XP Battery */
#define VE_PROD_ID_VALENCE_XP_BATTERY 0xB000

/* Valence BMS */
#define VE_PROD_ID_VALENCE_BMS 0xB001

/* Carlo Gavazzi Energy Meter */
#define VE_PROD_ID_CARLO_GAVAZZI_EM 0xB002

/* Redflow ZBM 2 Battery */
#define VE_PROD_ID_REDFLOW_ZBM2 0xB003

/* LG resu battery */
#define VE_PROD_ID_LG_RESU_BATTERY 0xB004

/* BMZ battery */
#define VE_PROD_ID_BMZ_BATTERY 0xB005

/* PV inverter measured on phase 2 of a Carlo Gavazzi Energy Meter */
#define VE_PROD_ID_CARLO_GAVAZZI_PIGGY_BACK 0xB006

/* sw vedirect interface */
#define VE_PROD_ID_SW_VEDIRECT_INTERFACE 0xFE00

/* sw base */
#define VE_PROD_ID_SW_BASE 0xFE00

/* sw ble interface */
#define VE_PROD_ID_SW_BLE_INTERFACE 0xFE01

/* sw mask, not a product.... */
#define VE_PROD_ID_SW_MASK 0xFF00

/* reserved */
#define VE_PROD_RESERVED 0xFFFE

/* No product set */
#define VE_PROD_NOT_SET 0xFFFF
/*[[[end]]]*/

VE_DCL	const char *veProductGetName(un16 prodId);

/// @}

#if 0
/* Products which are renamed */
#define VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_15A			_PROD_ID_BLUE_SOLAR_MPPT_70_15
#define	VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_50A			_PROD_ID_BLUE_SOLAR_MPPT_75_50
#define	VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_35A			_PROD_ID_BLUE_SOLAR_MPPT_150_35
#define	VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_15A_MK2		_PROD_ID_BLUE_SOLAR_MPPT_75_15
#define	VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_15A_MK3		_PROD_ID_BLUE_SOLAR_MPPT_100_15
#define	VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_30A			_PROD_ID_BLUE_SOLAR_MPPT_100_30
#define	VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_50A_MK2		_PROD_ID_BLUE_SOLAR_MPPT_100_50
#define	VE_OLD_PROD_ID_BLUE_SOLAR_MPPT_70A_MINI		_PROD_ID_BLUE_SOLAR_MPPT_150_70
#endif

/**
 * @ingroup VELIB_VECAN
 * @defgroup VELIB_VECAN_GROUPS	Group IDs
 */
/// @{

/// Solar battery chargers.
#define VE_GROUP_SOLAR_CHARGERS			10
/// Grid connected battery chargers (with input current limiting capabilities).
#define VE_GROUP_GRID_CHARGERS			20
/// Batteries
#define VE_GROUP_BATTERY				30
/// Blue Power Chargers
#define VE_GROUP_BLUE_POWER_CHARGERS	40
/// Gateway
#define VE_GROUP_GATEWAYS				50

#define VE_GROUP_RESERVED				0xFE
#define VE_GROUP_NOT_SET				0xFF

/// @}

/**
 * @ingroup VELIB_VECAN
 * @defgroup VELIB_VECAN_CHARGER_ALGORTIHM_VERSIONS	Charger Algorithm Versions (parallel charging)
 */
/// @{
/// Charger algorithm version Blue Solar.
#define VE_CHARGER_ALGORITHM_VERSION_MPPT			10
/// Charger algorithm versions Skylla-i. Note that the triple output must have higher priority since
/// it needs to report the status of the additional outputs (single output lacks this functionality).
#define VE_CHARGER_ALGORITHM_VERSION_SCB_1_OUTPUT	20
#define VE_CHARGER_ALGORITHM_VERSION_SCB_3_OUTPUTS	25

#define VE_CHARGER_ALGORITHM_VERSION_RESERVED		0xFE
#define VE_CHARGER_ALGORITHM_VERSION_NOT_SET		0xFF

/// @}


#endif
