#ifndef _VALUES_BMV_H_
#define _VALUES_BMV_H_

#include <velib/types/ve_item.h>

#include <values_common.h>

typedef struct
{
	VeItem relayState;
	VeItem alarm;
	VeItem lowVoltage;
	VeItem highVoltage;
	VeItem lowStarterVoltage;
	VeItem highStarterVoltage;
	VeItem lowSoc;
	// Lynx shunt alarms.
	VeItem lowFusedVoltage;
	VeItem highFusedVoltage;
	VeItem fuseBlown;
	VeItem highBatteryTemperature;
	VeItem lowBatteryTemperature;
	VeItem highInternalTemperature;
} BatteryAlarms;

typedef struct
{
	VeItem h[18];
	VeItem clear;
} History;

typedef struct {
	un16 pollTimer;
	veBool getHistory;
	veBool getProductInfo;
	veBool getRelayInfo;
	veBool getSettings;
	veBool pollBms;
	veBool checkSettings;

	/* For sub systems */
	MsgRouterHook hooks;
} VeCanBmv;

typedef struct
{
	VeItem locked;

	VeItem sync;
	VeItem zero;
	VeItem capacity;
	VeItem chargedVoltage;
	VeItem tailCurrent;
	VeItem chargedDetectionTime;
	VeItem chargeEfficiency;
	VeItem peukertExponent;
	VeItem currentThreshold;
	VeItem ttgDeltaT;
	VeItem dischargeFloor;
	VeItem lowSocClear;		/* For backwards compatibility */
	VeItem currentOffset;
} BatterySettings;

typedef struct
{
	VeItem lowVoltage;
	VeItem lowVoltageClear;
	VeItem highVoltage;
	VeItem highVoltageClear;
	VeItem lowStarterVoltage;
	VeItem lowStarterVoltageClear;
	VeItem highStarterVoltage;
	VeItem highStarterVoltageClear;
	VeItem lowSoc;
	VeItem lowSocClear;
	VeItem fuseBlown;
	VeItem highBatteryTemp;
	VeItem highBatteryTempClear;
	VeItem lowBatteryTemp;
	VeItem lowBatteryTempClear;
	VeItem highInternalTemp;
	VeItem highInternalTempClear;
} AlarmSettings;

typedef struct
{
	VeItem minEnabledTime;
	VeItem offDelay;
	VeItem mode;
	VeItem state;
	VeItem inverted;

	VeItem lowVoltage;
	VeItem lowVoltageClear;
	VeItem highVoltage;
	VeItem highVoltageClear;
	VeItem lowStarterVoltage;
	VeItem lowStarterVoltageClear;
	VeItem highStarterVoltage;
	VeItem highStarterVoltageClear;
	VeItem lowSoc;
	VeItem lowSocClear;
	VeItem fuseBlown;
	VeItem highBatteryTemp;
	VeItem highBatteryTempClear;
	VeItem lowBatteryTemp;
	VeItem lowBatteryTempClear;
	VeItem highInternalTemp;
	VeItem highInternalTempClear;
} RelaySettings;

typedef struct
{
	BatterySettings battery;
	AlarmSettings alarm;
	RelaySettings relay;
} Settings;

typedef struct VeBatteryS
{
	VeCanBmv can;

	/* The minimal fw version the settings are supported */
	un32 minSettingsVersion;
	/* The minimal fw version where the ttg discharge floor is separated from the relay set threshold */
	un32 minRelayLowSocVersion;
	/*
	 * Lynx Shunt <= v1.08 has bug in low Soc alarm: thresholds are multiplied by 100.
	 * In order to support the low Soc alarm, the thesholds accept steps of 10%.
	 * The bug has been fixed in >= v1.09
	 */
	veBool hasLowSocAlarmBug;

	un8 batteryInstance;
	VeItem cableVersion;
	DcStatus dcStatusBattery;
	DcStatus dcStatusAux;
	VeItem batteryTemperature;
	VeItem consumedAmphours;
	VeItem stateOfCharge;
	VeItem timeToGo;
	BatteryAlarms alarms;
	History history;
	Settings settings;

	VeItem hasTemperature;
	VeItem hasStarterVoltage;
	VeItem hasMidVoltage;
	VeItem hasSettings;
	VeItem dischargeFloorLinkedToRelay;
	VeItem restoreDefaults;

	VeSetting *settingsCtx;
} VeBattery;

veBool valuesBmvInit(VeSystem *system);
veBool valuesLynxShuntInit(VeSystem *system);

#endif
