#ifndef _VALUES_CHARGER_H_
#define _VALUES_CHARGER_H_

#include <velib/types/ve_item.h>

#include <values_common.h>

typedef struct
{
	VeItem pending;
	VeItem timeRemaining;
} Equalization;

typedef struct
{
	VeItem relayState;
	VeItem alarm;
	VeItem lowVoltage;
	VeItem highVoltage;
} Alarms;

#define VE_CAN_REQ_YESTERDAY_PMAX_GROUP		0x0001
#define VE_CAN_REQ_VE_REG_CHR_USER_YIELD	0x0002
#define VE_CAN_REQ_VE_REG_ERROR_CODE		0x0004
#define VE_CAN_CHECK_STANDALONE				0x0008
#define VE_CAN_SEND_RC_USED					0x0010
#define VE_CAN_REQ_VE_REG_AC_CURRENT_LIMIT	0x0020
#define VE_CAN_REQ_VE_REG_DC_INPUT_POWER	0x0040
#define VE_CAN_REQ_VE_REG_CHR_OUTPUTS		0x0080
#define VE_CAN_LINK_CONFIG_ERROR			0x8000

typedef struct {
	VeItem yield;
	VeItem maxPower;
} SolarHist;

/* CAN bus related states */
typedef struct {
	MsgRouterHook hooks;

	un16 pollTimer;
	un8 batteryInstance;
	un8 solarCellInstance;
	un16 flags;
	veBool standalone;
	un32 remoteControl;
	un16 suppressTimer;
	VeVariant tmpError;
	un16 configErrorTimer;
} VeChargerCan;

typedef struct {
	VeItem system;
	VeItem user;
	VeItem power;
} Yield;

typedef struct {
	VeItem voltage;
	VeItem current;
	VeItem power;
} AcStatus;

typedef struct
{
	VeChargerCan can;

	DcStatus dcStatus[3];
	VeItem temperature;
	VeItem state;
	VeItem mode;
	DcStatus pvStatus;
	Alarms alarms;
	Yield yield;
	VeItem errorCode;
	AcStatus acIn;
	VeItem acInCurrentLimit;
	SolarHist hist[2]; /* only solar chargers ofcourse */
	VeItem outputs;
} VeCharger;

void valuesInitSolarCharger(void);
veBool valuesChargerInit(VeSystem* system);
veBool valuesSolarChargerInit(VeSystem* system);
veBool valuesAcChargerInit(VeSystem* system);

#endif
