#ifndef _VELIB_INC_J1939_H_
#define _VELIB_INC_J1939_H_

// By default a node with single frame, fp and ACL support and queues is defined.

// NOTE: since these headers are included here, they should not include this file!
#include <velib/J1939/J1939_nmt.h>
#include <velib/J1939/J1939_rx.h>
#include <velib/J1939/J1939_sf.h>
#include <velib/J1939/J1939_tx.h>
#include <velib/nmea2k/n2k_fp.h>
#include <velib/types/ve_item.h>
#include <velib/vecan/dev_udf.h>
#include <velib/vecan/dev_n2k.h>
#include <velib/vecan/prod_types.h>
#include <velib/vecan/udf_name.h>

#include <msg_router.h>
#include <values_common.h>

/**
 * Structure holding free message and queues etc. This must be defined.
 */
typedef struct J1939Stack
{
	J1939RxVars		rx;				// input queue
	J1939TxVars		tx;				// output queue
	J1939SfVars		sf;				// single frame
	N2kFpVars		fp;				// fast packet
} J1939StackTp;

struct J1939Device;

typedef void VeProdScaledValueCallback(VeProdSgnDef const * signal, VeVariant* variant);
typedef void VeStoreSettingsCallback(struct J1939Device *dev);

/// Contains information per Local Device Function (RAM).
typedef struct J1939Device
{
	/// NAME of the device
	J1939Name 		name;
	/// Device's current NAD (not per definition valid, see flags).
	J1939Nad		nad;
	/// Flags if NAD is valid etc.
	un8				flags;
	/// Variables for automatic address resolution.
	J1939AclVars	acl;

	/* message definition */
	VeMsgNr msgCount;
	VeProdMsgDefConst const *veProdMsgDefConst;
	VeProdMsgDefVolatile *veProdMsgDefVolatile;
	VeProdMsgDefInvolatile *veProdMsgDefInvolatile;
	VeProdSgnDef const *signalDefinition;
	un8 *fpCounters;
	VeProdDevDef prod;
	VeProdScaledValueCallback *veProdScaledCb;
	VeStoreSettingsCallback *storeSettings;

	VeItem *nadItem;
	VeItem *instanceItem;
	veBool isAnnounced;

	struct J1939Device *next;
} J1939DeviceTp;

/**
 * Structure for Data Consumers to store information of remote functions
 * encountered on the bus.
 */
typedef struct J1939Func
{
	/* velib related, leave untouched */
	struct J1939Func*		next;
	J1939NmtVars			nmt;
	VeDevUdfVars			udf;
	VeDevN2kInfo			n2k;

	/* app variables */
	VeSystem *				system;
	MsgRouterHook			hooks;
	veBool					isMaster;
	veBool					needsProductId;
	veBool					isTank;

	VeItem					n2kProductName;
} J1939FuncTp;

#endif // _VELIB_INC_J1939_H_
