#include <stdlib.h>

#include <velib/base/base.h>
#include <velib/base/ve_string.h>
#include <velib/types/ve_item.h>

#include "dbus_service.h"
#include "values_common.h"
#include "values_tank.h"
#include "vecan_tank.h"

/**
 * Definitions how to make a textual representation of a value.
 * @see veVariantFmt in types/ve_variant_print.c.
 */
static VeVariantUnitFmt none = {0, ""};
static VeVariantUnitFmt percent = {1, "%"};
static VeVariantUnitFmt volume = {4, "m3"};

#define offset(a)	offsetof(VeTank, a)

static ItemInfo itemInfo[] =
{
	{"Level",		&percent,	offset(level),		8	},
	{"FluidType",	&none,		offset(fluidType),	8	},
	{"Capacity",	&volume,	offset(capacity),	8	},
	{"Remaining",	&volume,	offset(remaining),	8	}
};

#undef offset

static veBool veItemSetCapacity(VeItem *item, void *ctx, VeVariant *variant)
{
	VeSystem *system = (VeSystem *)ctx;

	VE_UNUSED(item);

	veVariantToFloat(variant);

	if (variant->type.tp != VE_FLOAT || !veVariantIsValid(variant))
		return veFalse;

	variant->value.Float *= 10000;
	veVariantFromFloat(variant, VE_UN32);

	return veCanTankSetCapacity(system, variant->value.UN32);
}

static veBool veItemSetFluidType(VeItem *item, void *ctx, VeVariant *variant)
{
	VeSystem *system = (VeSystem *)ctx;

	VE_UNUSED(item);

	veVariantToN32(variant);
	veVariantFromN32(variant, VE_UN8);

	/* Only 0-5 are valid, see PGN 127505:fluid type */
	if (variant->value.UN8 > 5)
		return veFalse;

	return veCanTankSetFluidType(system, variant->value.UN8);
}

/*
 * Create a system object with the corresponding item tree.
 *
 * The tree with items can be used to navigate through the values,
 * format / set / get them etc.
 */
veBool valuesTankInit(VeSystem *system)
{
	VeVariant variant;
	VeTank *tank = calloc(1, sizeof(VeTank));

	if (!tank)
		return veFalse;

	/* create the values tree to store the variables */
	system->canbusCtx = tank;
	valuesInitTree(itemInfo, ARRAY_LENGTH(itemInfo), &system->values, system);

	/* setup the CAN bus to fill them in */
	if (!veCanTankAdd(system)) {
		free(tank);
		return veFalse;
	}

	/* Settings */
	veItemSetSetter(&tank->capacity, veItemSetCapacity, system);
	veItemSetMin(&tank->capacity, veVariantFloat(&variant, 0));
	veItemSetMax(&tank->capacity, veVariantFloat(&variant, 429496));
	veItemSetDefault(&tank->capacity, veVariantFloat(&variant, 0));
	veItemSetSetter(&tank->fluidType, veItemSetFluidType, system);

	return veTrue;
}
