#ifndef _VELIB_VECAN_REGS_PAYLOAD_H_
#define _VELIB_VECAN_REGS_PAYLOAD_H_

/**
 * @addtogroup VELIB_VECAN_REG
 * @{
 */

/// Generic OK.
#define VACK_OK						0x0000
/// Used by UDF to indicate it is ready.
#define VACK_BEGIN					0x0100
/// Used by UDF to poll for more data.
#define VACK_CONT					0x0200

/// Error flag.
#define VACK_ERR					0x8000
/// Erroneous request, register unknown.
#define VACK_ERR_REQ				0x8000
/// Erroneous command, register unknown.
#define VACK_ERR_CMD				0x8100

/// Temporary failure.
#define VACK_ERR_BUSY				0x8200
/// Fatal error, invalid format etc.
#define VACK_ERR_INVALID			0x8300
/// Remote timeout.
#define VACK_ERR_TIMEOUT			0x8400
/// Too many invalid requests etc.
#define VACK_ERR_OVERFLOW			0x8500
/// Temporary failure, not completely initialiazed yet.
#define VACK_ERR_INITIALIZING		0x8600

/// Specific for VE_REG_UPDATE_DATA, can't boot (no valid application)
#define VACK_ERR_UPD_INVALID		0xC000

/// Specific for VE_REG_UPDATE_DATA
#define VACK_ERR_ERASING			0xC100

/// Specific for VE_REG_UPDATE_DATA
#define VACK_ERR_WRITE				0xC200

/// Specific for VE_REG_CONTROL, multi's can only controlled by 1 panel.
#define VACK_ERR_PANEL_PRESENT		0xC001

/// Internal, local timeout; not response reveived in time.
#define VACK_ERR_LOCAL_TIMEOUT		0xFFFE
/// Internal
#define VACK_INVALID				0xFFFF
/// Internal as well, used to not automatically send the value after a command
#define VACK_DO_NOT_SEND_VREG		0xFFFF

/// Register id is un16
typedef un16 VeRegAckCode;

/*
 * VE_REG_DEVICE_MODE	- 0x0200
 *
 *	un8 mode
 */
#define VE_REG_MODE_CHARGER				0x01
#define VE_REG_MODE_INVERTER			0x02
#define VE_REG_MODE_ON					0x03
#define VE_REG_MODE_OFF					0x04
#define VE_REG_MODE_ECO					0x05
#define VE_REG_MODE_STANDBY				0xFC
#define VE_REG_MODE_HIBERNATE			0xFD

/*
 * VE_REG_REMOTE_CONTROL_USED	- 0x0202
 *
 *	un32 flags
 */
#define VE_REG_RC_AC1_IN_LIMIT			0x00000001
#define VE_REG_RC_ON_OFF_MODE			0x00000002
#define VE_REG_RC_AC2_IN_LIMIT			0x00000004
#define VE_REG_RC_SEND_LEDS				0x00000100
#define VE_REG_RC_SEND_CELL_VOLTAGES	0x00010000
#define VE_REG_RC_SEND_RELAYS			0x00020000

/*
 * VE_REG_CHR_CUSTOM_STATE	- 0xEDD4
 *
 *	un8 state
 */
#define VE_REG_CUSTOM_STATE_SAFE_MODE		0x01
#define VE_REG_CUSTOM_STATE_TPTB_MODE		0x02
#define VE_REG_CUSTOM_STATE_REPEATED_ABS	0x04
#define VE_REG_CUSTOM_STATE_TEMP_DIM		0x10
#define VE_REG_CUSTOM_STATE_SENSE_DIM		0x20
#define VE_REG_CUSTOM_STATE_INP_CUR_DIM		0x40
#define VE_REG_CUSTOM_STATE_LOW_CUR_MODE	0x80

/*
 * VE_REG_CHR_RELAY_MODE - 0xEDD9
 *
 *  un8 mode
 */
#define VE_REG_RELAY_MODE_ALWAYS_OFF		0x00
#define VE_REG_RELAY_MODE_HIGH_PANEL_VOLTAGE 0x01
#define VE_REG_RELAY_MODE_HIGH_TEMPERATURE	0x02
#define VE_REG_RELAY_MODE_LOW_BATTERY_VOLTAGE 0x03
#define VE_REG_RELAY_MODE_EQUALIZATION		0x04
#define VE_REG_RELAY_MODE_ERROR_STATE		0x05
#define VE_REG_RELAY_MODE_LOW_TEMPERATURE	0x06
#define VE_REG_RELAY_MODE_HIGH_BATTERY_VOLTAGE 0x07
#define VE_REG_RELAY_MODE_FLOAT_OR_STORAGE	0x08
#define VE_REG_RELAY_MODE_PANEL_IRRADIATED	0x09
#define VE_REG_RELAY_MODE_LOAD_OUTPUT		0x0A
#define VE_REG_RELAY_MODE_REMOTE_CONTROL	0xFF

/*
 * VE_REG_DC_OUTPUT_CONTROL	- 0xEDAB
 *
 *	un8 mode
 */
#define VE_REG_DC_OUTPUT_CTRL_MASK			0x0F
#define VE_REG_DC_OUTPUT_CTRL_FORCE_OFF		0x00
#define VE_REG_DC_OUTPUT_CTRL_AUTO			0x01
#define VE_REG_DC_OUTPUT_CTRL_ALT1			0x02
#define VE_REG_DC_OUTPUT_CTRL_ALT2			0x03
#define VE_REG_DC_OUTPUT_CTRL_FORCE_ON		0x04
#define VE_REG_DC_OUTPUT_CTRL_USER1			0x05
#define VE_REG_DC_OUTPUT_CTRL_USER2			0x06
#define VE_REG_DC_OUTPUT_CTRL_LIGHT_FLAG	0x80

/*
 * VE_REG_VEDIRECT_PORT_TX_FUNCTION - 0xED9E
 *
 * un8 mode
 */
#define VE_REG_PORT_TX_VE_DIRECT			0x00
#define VE_REG_PORT_TX_001KWH_PULSES		0x01
#define VE_REG_PORT_TX_LIGHT_PWM_NORMAL		0x02
#define VE_REG_PORT_TX_LIGHT_PWM_INVERTED	0x03
#define VE_REG_PORT_TX_VIRTUAL_LOAD_OUTPUT	0x04
#define VE_REG_PORT_TX_VIRTUAL_RELAY		0x05

/*
 * VE_REG_VEDIRECT_PORT_RX_FUNCTION - 0xED98
 *
 * un8 mode
 */
#define VE_REG_PORT_RX_REMOTE_ON_OFF		0x00
#define VE_REG_PORT_RX_LOAD_OUTPUT_CONFIG	0x01
#define VE_REG_PORT_RX_LOAD_OUTPUT_ON_OFF	0x02

/*
 * VE_REG_LINK_COMMAND	- 0x2004
 *
 *	un8 command
 */
#define VE_REG_COMMAND_START_EQUALISE		0x01
#define VE_REG_COMMAND_STOP_EQUALISE		0x02
#define VE_REG_COMMAND_GUI_SYNC				0x03
#define VE_REG_COMMAND_DAY_SYNC				0x04

/*
 * VE_REG_LINK_NETWORK_MODE - 0x200E
 *
 * un8 mode
 */
#define VE_REG_NETWORK_MODE_STANDALONE		0x00
#define VE_REG_NETWORK_MODE_NETWORKED		0x01
#define VE_REG_NETWORK_MODE_REMOTE_CHARGE	0x02
#define VE_REG_NETWORK_MODE_REMOTE_HUB1		0x04
#define VE_REG_NETWORK_MODE_REMOTE_BMS		0x08
#define VE_REG_NETWORK_MODE_GROUP_MASTER	0x10
#define VE_REG_NETWORK_MODE_INSTANCE_MASTER	0x20

/*
 * VE_REG_LINK_NETWORK_STATUS - 0x200F
 *
 * un8 status
 */
#define VE_REG_NETWORK_STATUS_SLAVE				0x00
#define VE_REG_NETWORK_STATUS_GROUP_MASTER		0x01
#define VE_REG_NETWORK_STATUS_INSTANCE_MASTER	0x02
#define VE_REG_NETWORK_STATUS_STANDALONE		0x04


/* 
 * VE_REG_BACKLIGHT_ALWAYS_ON - 0x0400
 *
 * un8 mode
 */
#define VE_REG_BACKLIGHT_ALWAYS_ON_STAY_OFF		0x00 
#define VE_REG_BACKLIGHT_ALWAYS_ON_STAY_ON		0x01
#define VE_REG_BACKLIGHT_ALWAYS_ON_AUTOMATIC	0x02

/*
 * VE_REG_RELAY_MODE	- 0x034F
 *
 *	un8 mode
 */
#define VE_REG_RELAY_MODE_ALARM				0x00
#define VE_REG_RELAY_MODE_CHARGER			0x01
#define VE_REG_RELAY_MODE_REMOTE			0x02
#define VE_REG_RELAY_MODE_ALWAYS_OPEN		0x03

#define VE_VDATA_ION_BMS_STATE_WAIT_START				0
#define VE_VDATA_ION_BMS_STATE_BEFORE_BOOT				1
#define VE_VDATA_ION_BMS_STATE_BEFORE_BOOT_DELAY		2
#define VE_VDATA_ION_BMS_STATE_WAIT_BOOT				3
#define VE_VDATA_ION_BMS_STATE_INIT						4
#define VE_VDATA_ION_BMS_STATE_MEAS_BAT_VOLTAGE			5
#define VE_VDATA_ION_BMS_STATE_CALC_BAT_VOLTAGE			6
#define VE_VDATA_ION_BMS_STATE_WAIT_BUS_VOLTAGE			7
#define VE_VDATA_ION_BMS_STATE_WAIT_SHUNT				8
#define VE_VDATA_ION_BMS_STATE_RUNNING					9
#define VE_VDATA_ION_BMS_STATE_ERROR					10
#define VE_VDATA_ION_BMS_STATE_STANDBY					11

/// @ingroup VELIB_VECAN_REG
/// @defgroup VE_REG_ALARM_REASON
/// @{
/* VE_REG_ALARM_REASON_XXXX.. are flags/bitmasks (un16) for:
 *   VE_REG_ALARM_REASON     (0x031E)
 *   VE_REG_WARNING_REASON   (0x031C)
 *
 * The flags are ALARMS according BMV60 (not in regs.h).  The Macros are renamed to avoid lib conflicts
 * For MultiC/inverter not all alarms are supported and extra alarms are added (bit 8 and higher)
 * Also
 *   VE_REG_ALARM_REASON is triggered and defined by the first active protection, typically that is one reason.
 *   VE_REG_ALARM_REASON is not cleared until the inverter is operating normal again (e.g. by user reset or time out)
 *   VE_REG_WARNING_REASON always represents the current state of the protected levels.
 * @note regs_helpers has macros to detect multiple flags for grouped alarms.
 */
#define VE_REG_ALARM_REASON_LOW_VOLTAGE			0x0001		/* low battery voltage alarm */
#define VE_REG_ALARM_REASON_HIGH_VOLTAGE		0x0002		/* high battery voltage alarm */
#define VE_REG_ALARM_REASON_LOW_SOC				0x0004		/* low State Of Charge alarm */
#define VE_REG_ALARM_REASON_LOW_VOLTAGE2		0x0008		/* low voltage2 alarm */
#define VE_REG_ALARM_REASON_HIGH_VOLTAGE2		0x0010		/* high voltage2 alarm */
#define VE_REG_ALARM_REASON_LOW_TEMPERATURE		0x0020		/* low temperature alarm (also not connected transformer NTC)*/
#define VE_REG_ALARM_REASON_HIGH_TEMPERATURE	0x0040		/* high temperature alarm */
#define VE_REG_ALARM_REASON_MID_VOLTAGE			0x0080		/* mid voltage alarm */
#define VE_REG_ALARM_REASON_OVERLOAD			0x0100		/* e.g. based on Iinv^2 or Ipeak events count*/
#define VE_REG_ALARM_REASON_DC_RIPPLE			0x0200		/* e.g. indication for poor battery connection */
#define VE_REG_ALARM_REASON_LOW_V_AC_OUT		0x0400		/* e.g. in case of large load and low battery */
#define VE_REG_ALARM_REASON_HIGH_V_AC_OUT		0x0800		/* e.g. typ. when connected to other "mains" source, this will prevent the inverter-only to start*/
/// @}

/// @ingroup VELIB_VECAN_REG
/// @defgroup VELIB_VECAN_REG_SCB Skylla-i Control Board Vregs
/*
 * VE_REG_TST_TST_EXEC_CMD	- 0xEE7D
 *
 *	un16 command
 */
#define VE_REG_SCB_TST_CMD_INIT_CAL			0xF000 //Initialise factory calibration (reset to defaults)
#define VE_REG_SCB_TST_CMD_RELEASE			0xEF00 //Release set-points to application
#define VE_REG_SCB_TST_CMD_SET_RELAY		0xEE00 //LOW BYTE: 0=OFF, 1=ON
#define VE_REG_SCB_TST_CMD_SET_LEDS			0xED00 //LOW BYTE: 0=OFF, 1=ON (all)
#define VE_REG_SCB_TST_CMD_SET_DISPLAY		0xED00 //LOW BYTE: 0=OFF, 1=ON (all)
#define VE_REG_SCB_TST_CMD_SET_BUZZER		0xEC00 //LOW BYTE: 0=OFF, 1=ON
#define VE_REG_SCB_TST_CMD_SET_FAN			0xEB00 //LOW BYTE: SPEED (0=OFF)
#define VE_REG_SCB_TST_CMD_SET_ISET			0xEA00 //LOW BYTE: VALUE (0=OFF)
#define VE_REG_SCB_TST_CMD_SET_BACKLIGHT	0xE900 //LOW BYTE: 0=OFF, 1=ON
#define VE_REG_SCB_TST_CMD_SET_VSET			0xE800 //LOW BYTE: VALUE (0=OFF)
#define VE_REG_SCB_TST_CMD_SET_REM			0xE700 //LOW BYTE: VALUE (0=OFF)
/// @}

/// @ingroup VELIB_VECAN_REG
/// @defgroup VELIB_VECAN_REG_PPP Peak Power Pack Vregs
/// @{
/*
* VE_REG_TST_TST_EXEC_CMD	- 0xEE7D
*
*	un8 command, payload depends on command
*/
#define VE_REG_PPP_TST_CMD_INIT_CAL				0xF000	// Initialise factory calibration (reset to defaults)
#define VE_REG_PPP_TST_CMD_RELEASE				0xEF00	// Store calibration to flash -> no payload
#define VE_REG_PPP_TST_CMD_SET_CHARGE_DISABLE	0xEE00	// LSB: 0:charge enable, 1:charge disable
#define VE_REG_PPP_TST_CMD_SET_LED				0xED00	// LSB: 0:off, 1:blue, 2:red
#define VE_REG_PPP_TST_CMD_SET_MOVER			0xEC00	// LSB: 0:off, 1:on
#define VE_REG_PPP_TST_CMD_SET_COMFORT			0xEB00	// LSB: 0:off, 1:on
#define VE_REG_PPP_TST_CMD_CLEAR_STATS			0xEA00	// Clear stats -> no payload
/// @}

/// @ingroup VELIB_VECAN_REG
/// @defgroup VELIB_VECAN_REG_SRP Skylla-i Remote Panel Vregs
/*
 * VE_REG_TST_TST_EXEC_CMD	- 0xEE7D
 *
 *	un16 command
 */
#define VE_REG_SRP_TST_CMD_RELEASE			0xEF00 //Release set-points to application
#define VE_REG_SRP_TST_CMD_SET_LEDS			0xED00 //LOW BYTE: 0=OFF, 1=ON (all)
#define VE_REG_SRP_TST_CMD_SET_DISPLAY		0xEC00 //LOW BYTE: 0=OFF, 1=ON
/// @}

/// @ingroup VELIB_VECAN_REG
/// @defgroup VELIB_VECAN_REG_MPPT Blue Solar MPPT Vregs
/// @{
/*
 * VE_REG_TST_TST_EXEC_CMD	- 0xEE7D
 *
 *	un16 command
 */
#define VE_REG_MPPT_TST_CMD_INIT_CAL		0xF000 //Initialise factory calibration (reset to defaults)
#define VE_REG_MPPT_TST_CMD_RELEASE			0xEF00 //Release set-points to application
#define VE_REG_MPPT_TST_CMD_SET_RELAY		0xEE00 //LOW BYTE: 0=OFF, 1=ON
#define VE_REG_MPPT_TST_CMD_SET_DISPLAY		0xED00 //LOW BYTE: 0=OFF, 1=ON (all)
#define VE_REG_MPPT_TST_CMD_SET_BUZZER		0xEC00 //LOW BYTE: 0=OFF, 1=ON
#define VE_REG_MPPT_TST_CMD_SET_FAN			0xEB00 //LOW BYTE: SPEED (0=OFF)
#define VE_REG_MPPT_TST_CMD_SET_PWM1		0xEA00 //LOW BYTE: VALUE (0=OFF)
#define VE_REG_MPPT_TST_CMD_SET_BACKLIGHT	0xE900 //LOW BYTE: 0=OFF, 1=ON
#define VE_REG_MPPT_TST_CMD_SET_PWM2		0xE800 //LOW BYTE: VALUE (0=OFF)
#define VE_REG_MPPT_TST_CMD_SET_MODE		0xE700 //LOW BYTE: VALUE (0=DISCONTINUOUS,1=CONTINUOUS)
#define VE_REG_MPPT_TST_CMD_SET_PVSHORT		0xE600 //LOW BYTE: VALUE (0=OPEN,1=SHORT)
#define VE_REG_MPPT_TST_CMD_SET_REVERSE		0xE500 //LOW BYTE: VALUE (0=OPEN,1=SHORT)
/// @}

/*
 * VE_REG_BPC_LED_STATE	- 0xE000
 *
 * un32 led state
 *
 * To get the led value: (value >> VE_REG_BPC_LED_POS_xxx) & VE_REG_BPC_LED_VALUE_MASK
 */
#define VE_REG_BPC_LED_VALUE_OFF				0
#define VE_REG_BPC_LED_VALUE_ON					1
#define VE_REG_BPC_LED_VALUE_BLINK				2
#define VE_REG_BPC_LED_VALUE_BLINK_INVERTED		3
#define VE_REG_BPC_LED_VALUE_INVALID			7
#define VE_REG_BPC_LED_VALUE_MASK				7

#define VE_REG_BPC_LED_POS_TEST					0
#define VE_REG_BPC_LED_POS_BULK					3
#define VE_REG_BPC_LED_POS_ABS					6
#define VE_REG_BPC_LED_POS_FLOAT				9
#define VE_REG_BPC_LED_POS_STORAGE				12
#define VE_REG_BPC_LED_POS_NORMAL				15
#define VE_REG_BPC_LED_POS_HIGH					18
#define VE_REG_BPC_LED_POS_RECON				21
#define VE_REG_BPC_LED_POS_LI_ION				23

/*
 * VE_REG_TST_TST_EXEC_CMD	- 0xEE7D
 *
 *	un16 command
 */
#define VE_REG_BPC_TST_CMD_RELEASE			0xEF00 //Release set-points to application
#define VE_REG_BPC_TST_CMD_SET_RELAY		0xEE00 //LOW BYTE: 0=OFF, 1=ON
#define VE_REG_BPC_TST_CMD_SET_LED			0xED00 //LOW BYTE: 0=OFF, 1=ON (all)

/*
 * VE_REG_TST_TST_EXEC_CMD	- 0xEE7D
 *   un16 command
 *
 * LED TEST COMMANDS FOR PHOENIX_INVERTER, red and green commands can be ORed *
 *	hexprot payload un16 = ((un8)command << 8) & (un8)data
 *  command = ED,  data = LED dependent (2bit per LED: 0=normal, 1=blink, 2=off, 3=on)
 *
 * e.g.   :8 7D EE 00 11 ED (E4)  Both LEDs will blink (alternating)
 *        :8 7D EE 00 00 ED (F5)  Return to normal LED operation */
#define VE_REG_INV_TST_CMD_SET_LED_NORMAL		0xED00
#define VE_REG_INV_TST_CMD_SET_LED_GREEN_BLINK	0xED01
#define VE_REG_INV_TST_CMD_SET_LED_GREEN_OFF	0xED02
#define VE_REG_INV_TST_CMD_SET_LED_GREEN_ON		0xED03
#define VE_REG_INV_TST_CMD_SET_LED_RED_BLINK	0xED10
#define VE_REG_INV_TST_CMD_SET_LED_RED_OFF		0xED20
#define VE_REG_INV_TST_CMD_SET_LED_RED_ON		0xED30

#define VE_VDATA_ION_FLG_CHARGED						1
#define VE_VDATA_ION_FLG_ALMOST_CHARGED					(1ul << 1)
#define VE_VDATA_ION_FLG_DISCHARGED						(1ul << 2)
#define VE_VDATA_ION_FLG_ALMOST_DISCHARGED				(1ul << 3)
#define VE_VDATA_ION_FLG_CHARGING						(1ul << 4)
#define VE_VDATA_ION_FLG_DISCHARGING					(1ul << 5)
#define VE_VDATA_ION_FLG_BALANCE						(1ul << 6)
#define VE_VDATA_ION_FLG_RELAY_DISCHARGED				(1ul << 7)
#define VE_VDATA_ION_FLG_RELAY_CHARGED					(1ul << 8)
#define VE_VDATA_ION_FLG_ALRM_OVER_VOLTAGE				(1ul << 9)
#define VE_VDATA_ION_FLG_WARN_OVER_VOLTAGE				(1ul << 10)
#define VE_VDATA_ION_FLG_ALRM_UNDER_VOLTAGE				(1ul << 11)
#define VE_VDATA_ION_FLG_WARN_UNDER_VOLTAGE				(1ul << 12)
#define VE_VDATA_ION_FLG_WARN_CHARGE_CURRENT			(1ul << 13)
#define VE_VDATA_ION_FLG_WARN_DISCHARGE_CURRENT			(1ul << 14)
#define VE_VDATA_ION_FLG_ALRM_OVER_TEMPERATURE			(1ul << 15)
#define VE_VDATA_ION_FLG_WARN_OVER_TEMPERATURE			(1ul << 16)
#define VE_VDATA_ION_FLG_WARN_UNDR_TEMPERATURE_CHRG		(1ul << 17)
#define VE_VDATA_ION_FLG_ALRM_UNDR_TEMPERATURE_CHRG		(1ul << 18)
#define VE_VDATA_ION_FLG_WARN_UNDR_TEMPERATURE_DCHRG	(1ul << 19)
#define VE_VDATA_ION_FLG_ALRM_UNDR_TEMPARATURE_DCHRG	(1ul << 20)
#define VE_VDATA_ION_FLG_LOW_SOC						(1ul << 21)

#define VE_VDATA_ION_BMS_ERROR_NONE 					0	/* Note that this is a value, not a bit mask. */
#define VE_VDATA_ION_BMS_ERROR_RESERVED_1 				(1ul << 0)
#define VE_VDATA_ION_BMS_ERROR_BAT_INIT 				(1ul << 1)
#define VE_VDATA_ION_BMS_ERROR_NO_BAT 					(1ul << 2)
#define VE_VDATA_ION_BMS_ERROR_UNKNOWN_PC				(1ul << 3)
#define VE_VDATA_ION_BMS_ERROR_BAT_TYPE					(1ul << 4)
#define VE_VDATA_ION_BMS_ERROR_NR_OF_BAT				(1ul << 5)
#define VE_VDATA_ION_BMS_ERROR_NO_SHUNT_FND				(1ul << 6)
#define VE_VDATA_ION_BMS_ERROR_MEASURE					(1ul << 7)
#define VE_VDATA_ION_BMS_ERROR_CALCULATE				(1ul << 8)
#define VE_VDATA_ION_BMS_ERROR_BAT_NR_SER				(1ul << 9)
#define VE_VDATA_ION_BMS_ERROR_BAT_NR					(1ul << 10)
#define VE_VDATA_ION_BMS_ERROR_HW						(1ul << 11)
#define VE_VDATA_ION_BMS_ERROR_HW_WDT					(1ul << 12)
#define VE_VDATA_ION_BMS_ERROR_OV						(1ul << 13)
#define VE_VDATA_ION_BMS_ERROR_UV						(1ul << 14)
#define VE_VDATA_ION_BMS_ERROR_OTEMP					(1ul << 15)
#define VE_VDATA_ION_BMS_ERROR_UTEMP					(1ul << 16)
#define VE_VDATA_ION_BMS_ERROR_HW_CHARGE_PLUG			(1ul << 17)
#define VE_VDATA_ION_BMS_ERROR_HW_CHARGE				(1ul << 18)
#define VE_VDATA_ION_BMS_ERROR_HW_PRE_CHARGE_CHARGE		(1ul << 19)
#define VE_VDATA_ION_BMS_ERROR_HW_DISCHARGE				(1ul << 20)
#define VE_VDATA_ION_BMS_ERROR_HW_PRE_CHARGE_DISCHARGE	(1ul << 21)
#define VE_VDATA_ION_BMS_ERROR_HW_ADC_DATA				(1ul << 22)
#define VE_VDATA_ION_BMS_ERROR_SLAVE					(1ul << 23)
#define VE_VDATA_ION_BMS_ERROR_SLAVE_WARNING			(1ul << 24)
#define VE_VDATA_ION_BMS_ERROR_HW_PRE_CHARGE_CONTACTOR	(1ul << 25)
#define VE_VDATA_ION_BMS_ERROR_HW_CONTACTOR				(1ul << 26)
#define VE_VDATA_ION_BMS_ERROR_OUTPUT_OC				(1ul << 27)
#define VE_VDATA_ION_BMS_STATUS_SHUTDOWN				(1ul << 28)
#define VE_VDATA_ION_BMS_STATUS_INIT					(1ul << 29)
#define VE_VDATA_ION_BMS_STATUS_BALANCE					(1ul << 30)
#define VE_VDATA_ION_BMS_STATUS_RUN						(1ul << 31)

/*
 * VE_REG_BMS_FLAGS - 0x2100
 *
 * @remark Bit 0-21 maps 1-on-1 on VE_REG_LYNX_ION_FLAGS (0x0370). The
 * Lynx Ion (+ Shunt) has been develop by an external company (MG Electronics).
 * In order to prevent conflicts for bit 22-31 a new register has been
 * defined.
 * un32 flags
 */
#define VE_REG_BMS_FLG_CHARGED						(1ul << 0)
#define VE_REG_BMS_FLG_ALMOST_CHARGED				(1ul << 1)
#define VE_REG_BMS_FLG_DISCHARGED					(1ul << 2)
#define VE_REG_BMS_FLG_ALMOST_DISCHARGED			(1ul << 3)
#define VE_REG_BMS_FLG_CHARGING						(1ul << 4)
#define VE_REG_BMS_FLG_DISCHARGING					(1ul << 5)
#define VE_REG_BMS_FLG_BALANCE						(1ul << 6)
#define VE_REG_BMS_FLG_RELAY_DISCHARGED				(1ul << 7)
#define VE_REG_BMS_FLG_RELAY_CHARGED				(1ul << 8)
#define VE_REG_BMS_FLG_ALRM_OVER_VOLTAGE			(1ul << 9)
#define VE_REG_BMS_FLG_WARN_OVER_VOLTAGE			(1ul << 10)
#define VE_REG_BMS_FLG_ALRM_UNDER_VOLTAGE			(1ul << 11)
#define VE_REG_BMS_FLG_WARN_UNDER_VOLTAGE			(1ul << 12)
#define VE_REG_BMS_FLG_WARN_CHARGE_CURRENT			(1ul << 13)
#define VE_REG_BMS_FLG_WARN_DISCHARGE_CURRENT		(1ul << 14)
#define VE_REG_BMS_FLG_ALRM_OVER_TEMPERATURE		(1ul << 15)
#define VE_REG_BMS_FLG_WARN_OVER_TEMPERATURE		(1ul << 16)
#define VE_REG_BMS_FLG_WARN_UNDR_TEMPERATURE_CHRG	(1ul << 17)
#define VE_REG_BMS_FLG_ALRM_UNDR_TEMPERATURE_CHRG	(1ul << 18)
#define VE_REG_BMS_FLG_WARN_UNDR_TEMPERATURE_DCHRG	(1ul << 19)
#define VE_REG_BMS_FLG_ALRM_UNDR_TEMPARATURE_DCHRG	(1ul << 20)
#define VE_REG_BMS_FLG_LOW_SOC						(1ul << 21)
#define VE_REG_BMS_FLG_ALRM_UNDR_TEMPERATURE		(1ul << 22)
#define VE_REG_BMS_FLG_ALRM_SHORT_CIRCUIT			(1ul << 23)

/*
 * VE_REG_SMART_LITHIUM_ERROR_FLAGS - 0xEC80
 *
 * un32 flags
 */
#define VE_REG_SMART_LITHIUM_ERROR_NONE				0 /* Note that this is a value, not a bit mask. */
#define VE_REG_SMART_LITHIUM_ERROR_UNUSED			(1ul << 0)	// This bit is not yet used (by accident) and can be freely used in the future
#define VE_REG_SMART_LITHIUM_ERROR_COMM_ERROR		(1ul << 1)	// No data was received from the balancers for a long time
#define VE_REG_SMART_LITHIUM_ERROR_VOLTAGE01_ERROR	(1ul << 2)	// Balancer 0 and 1 got a different voltage (>250mV) for the same cell (#1 of 0..3)
#define VE_REG_SMART_LITHIUM_ERROR_VOLTAGE12_ERROR	(1ul << 3)	// Balancer 1 and 2 got a different voltage (>250mV) for the same cell (#2 of 0..3)

/*
 * VE_REG_CAPABILITIES1	- 0x0140
 *
 *	un32 capabilities
 */
#define VE_REG_CAPABILITIES1_HAS_LOAD_OUTPUT		(1ul)
#define VE_REG_CAPABILITIES1_HAS_ROTARY_ENCODER		(1ul << 1)
#define VE_REG_CAPABILITIES1_HAS_HISTORY_SUPPORT	(1ul << 2)
#define VE_REG_CAPABILITIES1_HAS_BATTERYSAFE_MODE	(1ul << 3)
#define VE_REG_CAPABILITIES1_HAS_ADAPTIVE_MODE		(1ul << 4)
#define VE_REG_CAPABILITIES1_HAS_MANUAL_EQUALISE	(1ul << 5)
#define VE_REG_CAPABILITIES1_HAS_AUTO_EQUALISE		(1ul << 6)
#define VE_REG_CAPABILITIES1_HAS_STORAGE_MODE		(1ul << 7)
#define VE_REG_CAPABILITIES1_HAS_REMOTE_ONOFF		(1ul << 8)
#define VE_REG_CAPABILITIES1_HAS_SOLAR_TIMER		(1ul << 9)
#define VE_REG_CAPABILITIES1_HAS_ALT_TX_FUNCTION	(1ul << 10)
#define VE_REG_CAPABILITIES1_HAS_USER_LOAD_SWITCH	(1ul << 11)
#define VE_REG_CAPABILITIES1_HAS_LOAD_CURRENT		(1ul << 12)
#define VE_REG_CAPABILITIES1_HAS_PANEL_CURRENT		(1ul << 13)
#define VE_REG_CAPABILITIES1_HAS_BMS_SUPPORT		(1ul << 14)
#define VE_REG_CAPABILITIES1_HAS_HUB1_SUPPORT		(1ul << 15)
#define VE_REG_CAPABILITIES1_HAS_PARALLEL_SUPPORT	(1ul << 16)
#define VE_REG_CAPABILITIES1_HAS_ALARM_RELAY1		(1ul << 17)
#define VE_REG_CAPABILITIES1_HAS_ALT_RX_FUNCTION	(1ul << 18)
#define VE_REG_CAPABILITIES1_HAS_VIRTUAL_LOAD_OUTPUT (1ul << 19)
#define VE_REG_CAPABILITIES1_HAS_VIRTUAL_RELAY		(1ul << 20)
#define VE_REG_CAPABILITIES1_HAS_DISPLAY			(1ul << 21)
#define VE_REG_CAPABILITIES1_HAS_LOW_CURRENT_MODE	(1ul << 22)
#define VE_REG_CAPABILITIES1_HAS_NIGHT_MODE			(1ul << 23)

/*
 * VE_REG_CAPABILITIES2	- 0x0141
 *
 *	un32 capabilities
 */
#define VE_REG_CAPABILITIES2_HAS_NO_TEXT			(1ul)
#define VE_REG_CAPABILITIES2_HAS_NO_ASYNC_HEX		(1ul << 1)
#define VE_REG_CAPABILITIES2_HAS_NO_HEX				(1ul << 2)

/*
 * VE_REG_CAPABILITIES3	- 0x0141
 *
 *	un32 capabilities
 */
#define VE_REG_CAPABILITIES3_HAS_TUNNEL_SUPPORT		(1ul)

/// @}

#endif
